# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions


class WorkflowVersionSummaryParams(typing_extensions.TypedDict):
    object: typing.Literal["workflow_version"]
    """
    The type of object. In this case, it will always be `"workflow_version"`.
    """

    id: str
    """
    The ID of the workflow version.
    
    Example: `"workflow_version_Zk9mNP12Qw4-yTv8BdR3H"`
    """

    version: str
    """
    The version of the workflow version.
    
    Example: `"3"`
    """

    name: typing.Optional[str]
    """
    The name of the workflow version.
    
    Example: `"Invoice Processing"`
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core.api_error import ApiError as core_api_error_ApiError
from ..types.api_error import ApiError as types_api_error_ApiError


class UnprocessableEntityError(core_api_error_ApiError):
    def __init__(self, body: types_api_error_ApiError, headers: typing.Optional[typing.Dict[str, str]] = None):
        super().__init__(status_code=422, headers=headers, body=body)



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.created_at import CreatedAt
from ..types.updated_at import UpdatedAt


class SplitterSummaryParams(typing_extensions.TypedDict):
    object: typing.Literal["splitter"]
    """
    The type of object. Will always be `"splitter"`.
    """

    id: str
    """
    The ID of the splitter.
    
    Example: `"spl_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    name: str
    """
    The name of the splitter.
    
    Example: `"Invoice Packet Splitter"`
    """

    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]
    updated_at: typing_extensions.Annotated[UpdatedAt, FieldMetadata(alias="updatedAt")]



# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_fields_array_output import LegacyFieldsArrayOutput
from .legacy_json_output import LegacyJsonOutput

LegacyExtractionOutput = typing.Union[LegacyJsonOutput, LegacyFieldsArrayOutput]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .edit_run import EditRun


class EditRunProcessedWebhookEvent(UncheckedBaseModel):
    event_id: typing_extensions.Annotated[str, FieldMetadata(alias="eventId")] = pydantic.Field(alias="eventId")
    """
    Unique identifier for the event
    """

    payload: EditRun

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


update_forward_refs(EditRunProcessedWebhookEvent)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..types.split_classification import SplitClassification

SplitClassificationsParams = typing.List[SplitClassification]



# This file was auto-generated by Fern from our API Definition.

import typing_extensions


class SplitRunsDeleteResponseParams(typing_extensions.TypedDict):
    id: str
    """
    The ID of the deleted split run
    """



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

import typing
from importlib import import_module

if typing.TYPE_CHECKING:
    from .types import (
        ApiError,
        ApiVersionEnum,
        ArrayStrategy,
        ArrayStrategyType,
        BatchProcessorRun,
        BatchProcessorRunMetrics,
        BatchProcessorRunOptions,
        BatchProcessorRunSource,
        BatchProcessorRunStatus,
        BatchRun,
        BatchRunEntity,
        BatchRunEntityVersion,
        BatchRunEntityVersion_ClassifierVersion,
        BatchRunEntityVersion_ExtractorVersion,
        BatchRunEntityVersion_SplitterVersion,
        BatchRunEntity_Classifier,
        BatchRunEntity_Extractor,
        BatchRunEntity_Splitter,
        BatchRunMetrics,
        BatchRunStatus,
        Block,
        BlockDetails,
        BlockMetadata,
        BlockMetadataPage,
        BlockPolygonItem,
        BlockType,
        BoundingBox,
        Chunk,
        ChunkMetadata,
        ChunkMetadataPageRange,
        ChunkType,
        Citation,
        CitationPage,
        Classification,
        Classifications,
        Classifier,
        ClassifierCreatedWebhookEvent,
        ClassifierDeletedWebhookEvent,
        ClassifierDraftUpdatedWebhookEvent,
        ClassifierSummary,
        ClassifierUpdatedWebhookEvent,
        ClassifierVersion,
        ClassifierVersionPublishedWebhookEvent,
        ClassifierVersionSummary,
        ClassifyAdvancedOptions,
        ClassifyAdvancedOptionsContext,
        ClassifyConfig,
        ClassifyConfigBaseProcessor,
        ClassifyOutput,
        ClassifyRequestClassifier,
        ClassifyRequestFile,
        ClassifyResult,
        ClassifyRun,
        ClassifyRunFailedWebhookEvent,
        ClassifyRunProcessedWebhookEvent,
        ClassifyRunSummary,
        ClassifyStepRun,
        ClassifyStepRunStep,
        ConditionalExtractResult,
        ConditionalExtractStepRun,
        ConditionalExtractStepRunStep,
        CreatedAt,
        EditBoundingBox,
        EditConfig,
        EditConfigAdvancedOptions,
        EditJson,
        EditJsonExtendEditFieldType,
        EditObjectJson,
        EditRequestFile,
        EditRootJson,
        EditRun,
        EditRunFailedWebhookEvent,
        EditRunMetrics,
        EditRunOutput,
        EditRunOutputEditedFile,
        EditRunProcessedWebhookEvent,
        EditRunStatus,
        EditTextOptions,
        EmptyBlockDetails,
        Enum,
        EnumOption,
        EvaluationSet,
        EvaluationSetEntity,
        EvaluationSetEntity_Classifier,
        EvaluationSetEntity_Extractor,
        EvaluationSetEntity_Splitter,
        EvaluationSetItem,
        EvaluationSetItemSummary,
        EvaluationSetRun,
        EvaluationSetRunEntity,
        EvaluationSetRunEntityVersion,
        EvaluationSetRunEntityVersion_ClassifierVersion,
        EvaluationSetRunEntityVersion_ExtractorVersion,
        EvaluationSetRunEntityVersion_SplitterVersion,
        EvaluationSetRunEntity_Classifier,
        EvaluationSetRunEntity_Extractor,
        EvaluationSetRunEntity_Splitter,
        EvaluationSetRunMetrics,
        EvaluationSetRunOptions,
        ExcelSheetRange,
        ExternalDataValidationResult,
        ExternalDataValidationResultResponse,
        ExternalDataValidationStepRun,
        ExternalDataValidationStepRunStep,
        ExtractAdvancedOptions,
        ExtractAdvancedOptionsArrayCitationStrategy,
        ExtractAdvancedOptionsExcelSheetSelectionStrategy,
        ExtractAdvancedOptionsReviewAgent,
        ExtractChunkingOptions,
        ExtractChunkingOptionsChunkSelectionStrategy,
        ExtractChunkingOptionsChunkingStrategy,
        ExtractConfig,
        ExtractConfigJson,
        ExtractConfigJsonBaseProcessor,
        ExtractConfigLegacy,
        ExtractConfigLegacyBaseProcessor,
        ExtractOutput,
        ExtractOutputEdits,
        ExtractOutputJson,
        ExtractOutputLegacy,
        ExtractOutputMetadata,
        ExtractOutputMetadataValue,
        ExtractRequestExtractor,
        ExtractRequestFile,
        ExtractResult,
        ExtractRun,
        ExtractRunFailedWebhookEvent,
        ExtractRunProcessedWebhookEvent,
        ExtractRunSummary,
        ExtractStepRun,
        ExtractStepRunStep,
        ExtractionField,
        ExtractionFieldResult,
        ExtractionFieldResultReference,
        ExtractionFieldResultReferenceBoundingBoxesItem,
        ExtractionFieldResultType,
        ExtractionFieldType,
        Extractor,
        ExtractorCreatedWebhookEvent,
        ExtractorDeletedWebhookEvent,
        ExtractorDraftUpdatedWebhookEvent,
        ExtractorSummary,
        ExtractorUpdatedWebhookEvent,
        ExtractorVersion,
        ExtractorVersionPublishedWebhookEvent,
        ExtractorVersionSummary,
        FigureDetails,
        FigureDetailsFigureType,
        File,
        FileContents,
        FileContentsPagesItem,
        FileContentsSectionsItem,
        FileContentsSheetsItem,
        FileFromId,
        FileFromText,
        FileFromUrl,
        FileMetadata,
        FileSummary,
        FileType,
        Insight,
        JsonObject,
        LegacyBatchProcessorRun,
        LegacyBatchProcessorRunMetrics,
        LegacyBatchProcessorRunOptions,
        LegacyBatchProcessorRunSource,
        LegacyBatchProcessorRunStatus,
        LegacyClassification,
        LegacyClassificationAdvancedOptions,
        LegacyClassificationAdvancedOptionsContext,
        LegacyClassificationConfig,
        LegacyClassificationConfigBaseProcessor,
        LegacyClassifierOutput,
        LegacyDocumentProcessorRunCredits,
        LegacyError,
        LegacyExtendError,
        LegacyExtractChunkingOptions,
        LegacyExtractChunkingOptionsChunkSelectionStrategy,
        LegacyExtractChunkingOptionsChunkingStrategy,
        LegacyExtractionAdvancedOptions,
        LegacyExtractionAdvancedOptionsArrayCitationStrategy,
        LegacyExtractionAdvancedOptionsExcelSheetSelectionStrategy,
        LegacyExtractionAdvancedOptionsReviewAgent,
        LegacyExtractionConfig,
        LegacyExtractionConfigBaseProcessor,
        LegacyExtractionField,
        LegacyExtractionFieldResult,
        LegacyExtractionFieldResultType,
        LegacyExtractionFieldType,
        LegacyExtractionOutput,
        LegacyExtractionOutputEdits,
        LegacyFieldsArrayOutput,
        LegacyJsonObject,
        LegacyJsonOutput,
        LegacyJsonOutputMetadataValue,
        LegacyJsonOutputMetadataValueCitationsItem,
        LegacyJsonOutputMetadataValueCitationsItemPolygonItem,
        LegacyListProcessorsProcessor,
        LegacyListProcessorsProcessorVersion,
        LegacyListProcessorsResponse,
        LegacyMaxPageSize,
        LegacyNextPageToken,
        LegacyProcessor,
        LegacyProcessorId,
        LegacyProcessorOutput,
        LegacyProcessorRun,
        LegacyProcessorRunConfig,
        LegacyProcessorRunConfig_Classify,
        LegacyProcessorRunConfig_Extract,
        LegacyProcessorRunConfig_Splitter,
        LegacyProcessorRunFileInput,
        LegacyProcessorRunMergedProcessorsItem,
        LegacyProcessorRunSummary,
        LegacyProcessorRunSummaryType,
        LegacyProcessorRunType,
        LegacyProcessorStatus,
        LegacyProcessorType,
        LegacyProcessorVersion,
        LegacyProcessorVersionConfig,
        LegacyProcessorVersionConfig_Classify,
        LegacyProcessorVersionConfig_Extract,
        LegacyProcessorVersionConfig_Splitter,
        LegacyProvidedClassifierOutput,
        LegacyProvidedExtractionFieldResult,
        LegacyProvidedExtractionFieldResultType,
        LegacyProvidedExtractionOutput,
        LegacyProvidedFieldsArrayOutput,
        LegacyProvidedJsonOutput,
        LegacyProvidedProcessorOutput,
        LegacyProvidedSplitterOutput,
        LegacyProvidedSplitterOutputSplitsItem,
        LegacySortByEnum,
        LegacySortDirEnum,
        LegacySplitterAdvancedOptions,
        LegacySplitterAdvancedOptionsSplitMethod,
        LegacySplitterConfig,
        LegacySplitterConfigBaseProcessor,
        LegacySplitterOutput,
        LegacySplitterOutputSplitsItem,
        MaxPageSize,
        MergeExtractResult,
        MergeExtractResultMergedExtractorsItem,
        MergeExtractStepRun,
        MergeExtractStepRunStep,
        NextPageToken,
        PageRanges,
        PageRangesItem,
        ParentSplit,
        ParseConfig,
        ParseConfigAdvancedOptions,
        ParseConfigAdvancedOptionsReturnOcr,
        ParseConfigBlockOptions,
        ParseConfigBlockOptionsFigures,
        ParseConfigBlockOptionsTables,
        ParseConfigBlockOptionsTablesAgentic,
        ParseConfigBlockOptionsTablesTargetFormat,
        ParseConfigBlockOptionsText,
        ParseConfigBlockOptionsTextAgentic,
        ParseConfigChunkingStrategy,
        ParseConfigChunkingStrategyOptions,
        ParseConfigChunkingStrategyType,
        ParseConfigEngine,
        ParseConfigTarget,
        ParseRequestFile,
        ParseRequestResponseType,
        ParseResult,
        ParseRun,
        ParseRunFailedWebhookEvent,
        ParseRunMetrics,
        ParseRunOutput,
        ParseRunOutputOcr,
        ParseRunOutputOcrWordsItem,
        ParseRunProcessedWebhookEvent,
        ParseRunStatus,
        ParseRunStatusEnum,
        ParseRunStatusStatus,
        ParseStepRun,
        ParseStepRunStep,
        Polygon,
        ProcessorRunStatus,
        ProcessorVersionString,
        ProvidedClassifyOutput,
        ProvidedExtractOutput,
        ProvidedProcessorOutput,
        ProvidedSplitOutput,
        ProvidedSplitOutputSplitsItem,
        ReleaseType,
        RuleValidationResult,
        RuleValidationResultRulesItem,
        RuleValidationResultRulesItemFailureReason,
        RuleValidationStepRun,
        RuleValidationStepRunStep,
        RunMetadata,
        RunPriority,
        RunSecrets,
        RunSource,
        RunSourceId,
        RunUsage,
        SortBy,
        SortDir,
        SplitAdvancedOptions,
        SplitAdvancedOptionsSplitMethod,
        SplitConfig,
        SplitConfigBaseProcessor,
        SplitOutput,
        SplitOutputSplitsItem,
        SplitRequestFile,
        SplitRequestSplitter,
        SplitResult,
        SplitRun,
        SplitRunFailedWebhookEvent,
        SplitRunProcessedWebhookEvent,
        SplitRunSummary,
        SplitStepRun,
        SplitStepRunStep,
        Splitter,
        SplitterCreatedWebhookEvent,
        SplitterDeletedWebhookEvent,
        SplitterDraftUpdatedWebhookEvent,
        SplitterSummary,
        SplitterUpdatedWebhookEvent,
        SplitterVersion,
        SplitterVersionPublishedWebhookEvent,
        SplitterVersionSummary,
        StepRun,
        StepRunBase,
        StepRunBaseStatus,
        TableCellDetails,
        TableDetails,
        TooManyRequestsErrorBody,
        UpdatedAt,
        VersionDescription,
        WebhookEvent,
        WebhookEvent_ClassifierCreated,
        WebhookEvent_ClassifierDeleted,
        WebhookEvent_ClassifierDraftUpdated,
        WebhookEvent_ClassifierUpdated,
        WebhookEvent_ClassifierVersionPublished,
        WebhookEvent_ClassifyRunFailed,
        WebhookEvent_ClassifyRunProcessed,
        WebhookEvent_EditRunFailed,
        WebhookEvent_EditRunProcessed,
        WebhookEvent_ExtractRunFailed,
        WebhookEvent_ExtractRunProcessed,
        WebhookEvent_ExtractorCreated,
        WebhookEvent_ExtractorDeleted,
        WebhookEvent_ExtractorDraftUpdated,
        WebhookEvent_ExtractorUpdated,
        WebhookEvent_ExtractorVersionPublished,
        WebhookEvent_ParseRunFailed,
        WebhookEvent_ParseRunProcessed,
        WebhookEvent_SplitRunFailed,
        WebhookEvent_SplitRunProcessed,
        WebhookEvent_SplitterCreated,
        WebhookEvent_SplitterDeleted,
        WebhookEvent_SplitterDraftUpdated,
        WebhookEvent_SplitterUpdated,
        WebhookEvent_SplitterVersionPublished,
        WebhookEvent_WorkflowCreated,
        WebhookEvent_WorkflowDeleted,
        WebhookEvent_WorkflowDeployed,
        WebhookEvent_WorkflowRunCancelled,
        WebhookEvent_WorkflowRunCompleted,
        WebhookEvent_WorkflowRunFailed,
        WebhookEvent_WorkflowRunNeedsReview,
        WebhookEvent_WorkflowRunRejected,
        WebhookEvent_WorkflowRunStepRunProcessed,
        Workflow,
        WorkflowCreatedWebhookEvent,
        WorkflowDeletedWebhookEvent,
        WorkflowDeployedWebhookEvent,
        WorkflowReference,
        WorkflowRun,
        WorkflowRunCancelledWebhookEvent,
        WorkflowRunCompletedWebhookEvent,
        WorkflowRunFailedWebhookEvent,
        WorkflowRunNeedsReviewWebhookEvent,
        WorkflowRunRejectedWebhookEvent,
        WorkflowRunStatus,
        WorkflowRunStepRunProcessedWebhookEvent,
        WorkflowRunSummary,
        WorkflowStepBase,
        WorkflowSummary,
        WorkflowVersion,
        WorkflowVersionSummary,
    )
    from .errors import (
        BadRequestError,
        ForbiddenError,
        InternalServerError,
        NotFoundError,
        PaymentRequiredError,
        TooManyRequestsError,
        UnauthorizedError,
        UnprocessableEntityError,
    )
    from . import (
        batch_processor_run,
        classifier_versions,
        classifiers,
        classify_runs,
        edit_runs,
        evaluation_set_items,
        evaluation_set_runs,
        evaluation_sets,
        extract_runs,
        extractor_versions,
        extractors,
        files,
        parse_runs,
        processor,
        processor_run,
        processor_version,
        split_runs,
        splitter_versions,
        splitters,
        workflow_runs,
        workflows,
    )
    from .batch_processor_run import BatchProcessorRunGetResponse, BatchProcessorRunGetResponseParams
    from .classifier_versions import ClassifierVersionsListResponse, ClassifierVersionsListResponseParams
    from .classifiers import ClassifiersListResponse, ClassifiersListResponseParams
    from .classify_runs import (
        ClassifyRunsCreateRequestClassifier,
        ClassifyRunsCreateRequestClassifierParams,
        ClassifyRunsCreateRequestFile,
        ClassifyRunsCreateRequestFileParams,
        ClassifyRunsDeleteResponse,
        ClassifyRunsDeleteResponseParams,
        ClassifyRunsListResponse,
        ClassifyRunsListResponseParams,
    )
    from .wrapper import AsyncExtend, Extend, Webhooks, PollingOptions, PollingTimeoutError
    from .edit_runs import (
        EditRunsCreateRequestFile,
        EditRunsCreateRequestFileParams,
        EditRunsDeleteResponse,
        EditRunsDeleteResponseParams,
    )
    from .environment import ExtendEnvironment
    from .evaluation_set_items import (
        EvaluationSetItemsCreateRequestItemsItem,
        EvaluationSetItemsCreateRequestItemsItemParams,
        EvaluationSetItemsCreateResponse,
        EvaluationSetItemsCreateResponseParams,
        EvaluationSetItemsDeleteResponse,
        EvaluationSetItemsDeleteResponseParams,
        EvaluationSetItemsListResponse,
        EvaluationSetItemsListResponseParams,
    )
    from .evaluation_sets import EvaluationSetsListResponse, EvaluationSetsListResponseParams
    from .extract_runs import (
        ExtractRunsCreateRequestExtractor,
        ExtractRunsCreateRequestExtractorParams,
        ExtractRunsCreateRequestFile,
        ExtractRunsCreateRequestFileParams,
        ExtractRunsDeleteResponse,
        ExtractRunsDeleteResponseParams,
        ExtractRunsListResponse,
        ExtractRunsListResponseParams,
    )
    from .extractor_versions import ExtractorVersionsListResponse, ExtractorVersionsListResponseParams
    from .extractors import ExtractorsListResponse, ExtractorsListResponseParams
    from .files import FilesDeleteResponse, FilesDeleteResponseParams, FilesListResponse, FilesListResponseParams
    from .parse_runs import (
        ParseRunsCreateRequestFile,
        ParseRunsCreateRequestFileParams,
        ParseRunsDeleteResponse,
        ParseRunsDeleteResponseParams,
        ParseRunsRetrieveRequestResponseType,
    )
    from .processor import (
        ProcessorCreateRequestConfig,
        ProcessorCreateRequestConfigParams,
        ProcessorCreateRequestConfig_Classify,
        ProcessorCreateRequestConfig_ClassifyParams,
        ProcessorCreateRequestConfig_Extract,
        ProcessorCreateRequestConfig_ExtractParams,
        ProcessorCreateRequestConfig_Splitter,
        ProcessorCreateRequestConfig_SplitterParams,
        ProcessorCreateResponse,
        ProcessorCreateResponseParams,
        ProcessorListRequestSortBy,
        ProcessorListRequestSortDir,
        ProcessorUpdateRequestConfig,
        ProcessorUpdateRequestConfigParams,
        ProcessorUpdateRequestConfig_Classify,
        ProcessorUpdateRequestConfig_ClassifyParams,
        ProcessorUpdateRequestConfig_Extract,
        ProcessorUpdateRequestConfig_ExtractParams,
        ProcessorUpdateRequestConfig_Splitter,
        ProcessorUpdateRequestConfig_SplitterParams,
        ProcessorUpdateResponse,
        ProcessorUpdateResponseParams,
    )
    from .processor_run import (
        ProcessorRunCancelResponse,
        ProcessorRunCancelResponseParams,
        ProcessorRunCreateRequestConfig,
        ProcessorRunCreateRequestConfigParams,
        ProcessorRunCreateRequestConfig_Classify,
        ProcessorRunCreateRequestConfig_ClassifyParams,
        ProcessorRunCreateRequestConfig_Extract,
        ProcessorRunCreateRequestConfig_ExtractParams,
        ProcessorRunCreateRequestConfig_Splitter,
        ProcessorRunCreateRequestConfig_SplitterParams,
        ProcessorRunCreateResponse,
        ProcessorRunCreateResponseParams,
        ProcessorRunDeleteResponse,
        ProcessorRunDeleteResponseParams,
        ProcessorRunGetResponse,
        ProcessorRunGetResponseParams,
        ProcessorRunListRequestSource,
        ProcessorRunListResponse,
        ProcessorRunListResponseParams,
    )
    from .processor_version import (
        ProcessorVersionCreateRequestConfig,
        ProcessorVersionCreateRequestConfigParams,
        ProcessorVersionCreateRequestConfig_Classify,
        ProcessorVersionCreateRequestConfig_ClassifyParams,
        ProcessorVersionCreateRequestConfig_Extract,
        ProcessorVersionCreateRequestConfig_ExtractParams,
        ProcessorVersionCreateRequestConfig_Splitter,
        ProcessorVersionCreateRequestConfig_SplitterParams,
        ProcessorVersionCreateRequestReleaseType,
        ProcessorVersionCreateResponse,
        ProcessorVersionCreateResponseParams,
        ProcessorVersionGetResponse,
        ProcessorVersionGetResponseParams,
        ProcessorVersionListResponse,
        ProcessorVersionListResponseParams,
    )
    from .requests import (
        ApiErrorParams,
        ArrayStrategyParams,
        BatchProcessorRunMetricsParams,
        BatchProcessorRunOptionsParams,
        BatchProcessorRunParams,
        BatchRunEntityParams,
        BatchRunEntityVersionParams,
        BatchRunEntityVersion_ClassifierVersionParams,
        BatchRunEntityVersion_ExtractorVersionParams,
        BatchRunEntityVersion_SplitterVersionParams,
        BatchRunEntity_ClassifierParams,
        BatchRunEntity_ExtractorParams,
        BatchRunEntity_SplitterParams,
        BatchRunMetricsParams,
        BatchRunParams,
        BlockDetailsParams,
        BlockMetadataPageParams,
        BlockMetadataParams,
        BlockParams,
        BlockPolygonItemParams,
        BoundingBoxParams,
        ChunkMetadataPageRangeParams,
        ChunkMetadataParams,
        ChunkParams,
        CitationPageParams,
        CitationParams,
        ClassificationParams,
        ClassificationsParams,
        ClassifierCreatedWebhookEventParams,
        ClassifierDeletedWebhookEventParams,
        ClassifierDraftUpdatedWebhookEventParams,
        ClassifierParams,
        ClassifierSummaryParams,
        ClassifierUpdatedWebhookEventParams,
        ClassifierVersionParams,
        ClassifierVersionPublishedWebhookEventParams,
        ClassifierVersionSummaryParams,
        ClassifyAdvancedOptionsParams,
        ClassifyConfigParams,
        ClassifyOutputParams,
        ClassifyRequestClassifierParams,
        ClassifyRequestFileParams,
        ClassifyResultParams,
        ClassifyRunFailedWebhookEventParams,
        ClassifyRunParams,
        ClassifyRunProcessedWebhookEventParams,
        ClassifyRunSummaryParams,
        ClassifyStepRunParams,
        ClassifyStepRunStepParams,
        ConditionalExtractResultParams,
        ConditionalExtractStepRunParams,
        ConditionalExtractStepRunStepParams,
        EditBoundingBoxParams,
        EditConfigAdvancedOptionsParams,
        EditConfigParams,
        EditJsonParams,
        EditObjectJsonParams,
        EditRequestFileParams,
        EditRootJsonParams,
        EditRunFailedWebhookEventParams,
        EditRunMetricsParams,
        EditRunOutputEditedFileParams,
        EditRunOutputParams,
        EditRunParams,
        EditRunProcessedWebhookEventParams,
        EditTextOptionsParams,
        EnumOptionParams,
        EnumParams,
        EvaluationSetEntityParams,
        EvaluationSetEntity_ClassifierParams,
        EvaluationSetEntity_ExtractorParams,
        EvaluationSetEntity_SplitterParams,
        EvaluationSetItemParams,
        EvaluationSetItemSummaryParams,
        EvaluationSetParams,
        EvaluationSetRunEntityParams,
        EvaluationSetRunEntityVersionParams,
        EvaluationSetRunEntityVersion_ClassifierVersionParams,
        EvaluationSetRunEntityVersion_ExtractorVersionParams,
        EvaluationSetRunEntityVersion_SplitterVersionParams,
        EvaluationSetRunEntity_ClassifierParams,
        EvaluationSetRunEntity_ExtractorParams,
        EvaluationSetRunEntity_SplitterParams,
        EvaluationSetRunMetricsParams,
        EvaluationSetRunOptionsParams,
        EvaluationSetRunParams,
        ExcelSheetRangeParams,
        ExternalDataValidationResultParams,
        ExternalDataValidationResultResponseParams,
        ExternalDataValidationStepRunParams,
        ExternalDataValidationStepRunStepParams,
        ExtractAdvancedOptionsParams,
        ExtractAdvancedOptionsReviewAgentParams,
        ExtractChunkingOptionsParams,
        ExtractConfigJsonParams,
        ExtractConfigLegacyParams,
        ExtractConfigParams,
        ExtractOutputEditsParams,
        ExtractOutputJsonParams,
        ExtractOutputLegacyParams,
        ExtractOutputMetadataParams,
        ExtractOutputMetadataValueParams,
        ExtractOutputParams,
        ExtractRequestExtractorParams,
        ExtractRequestFileParams,
        ExtractResultParams,
        ExtractRunFailedWebhookEventParams,
        ExtractRunParams,
        ExtractRunProcessedWebhookEventParams,
        ExtractRunSummaryParams,
        ExtractStepRunParams,
        ExtractStepRunStepParams,
        ExtractionFieldParams,
        ExtractionFieldResultParams,
        ExtractionFieldResultReferenceBoundingBoxesItemParams,
        ExtractionFieldResultReferenceParams,
        ExtractorCreatedWebhookEventParams,
        ExtractorDeletedWebhookEventParams,
        ExtractorDraftUpdatedWebhookEventParams,
        ExtractorParams,
        ExtractorSummaryParams,
        ExtractorUpdatedWebhookEventParams,
        ExtractorVersionParams,
        ExtractorVersionPublishedWebhookEventParams,
        ExtractorVersionSummaryParams,
        FigureDetailsParams,
        FileContentsPagesItemParams,
        FileContentsParams,
        FileContentsSectionsItemParams,
        FileContentsSheetsItemParams,
        FileFromIdParams,
        FileFromTextParams,
        FileFromUrlParams,
        FileMetadataParams,
        FileParams,
        FileSummaryParams,
        InsightParams,
        LegacyBatchProcessorRunMetricsParams,
        LegacyBatchProcessorRunOptionsParams,
        LegacyBatchProcessorRunParams,
        LegacyClassificationAdvancedOptionsParams,
        LegacyClassificationConfigParams,
        LegacyClassificationParams,
        LegacyClassifierOutputParams,
        LegacyDocumentProcessorRunCreditsParams,
        LegacyErrorParams,
        LegacyExtendErrorParams,
        LegacyExtractChunkingOptionsParams,
        LegacyExtractionAdvancedOptionsParams,
        LegacyExtractionAdvancedOptionsReviewAgentParams,
        LegacyExtractionConfigParams,
        LegacyExtractionFieldParams,
        LegacyExtractionFieldResultParams,
        LegacyExtractionOutputEditsParams,
        LegacyExtractionOutputParams,
        LegacyFieldsArrayOutputParams,
        LegacyJsonOutputMetadataValueCitationsItemParams,
        LegacyJsonOutputMetadataValueCitationsItemPolygonItemParams,
        LegacyJsonOutputMetadataValueParams,
        LegacyJsonOutputParams,
        LegacyListProcessorsProcessorParams,
        LegacyListProcessorsProcessorVersionParams,
        LegacyListProcessorsResponseParams,
        LegacyProcessorOutputParams,
        LegacyProcessorParams,
        LegacyProcessorRunConfigParams,
        LegacyProcessorRunConfig_ClassifyParams,
        LegacyProcessorRunConfig_ExtractParams,
        LegacyProcessorRunConfig_SplitterParams,
        LegacyProcessorRunFileInputParams,
        LegacyProcessorRunMergedProcessorsItemParams,
        LegacyProcessorRunParams,
        LegacyProcessorRunSummaryParams,
        LegacyProcessorVersionConfigParams,
        LegacyProcessorVersionConfig_ClassifyParams,
        LegacyProcessorVersionConfig_ExtractParams,
        LegacyProcessorVersionConfig_SplitterParams,
        LegacyProcessorVersionParams,
        LegacyProvidedClassifierOutputParams,
        LegacyProvidedExtractionFieldResultParams,
        LegacyProvidedExtractionOutputParams,
        LegacyProvidedFieldsArrayOutputParams,
        LegacyProvidedJsonOutputParams,
        LegacyProvidedProcessorOutputParams,
        LegacyProvidedSplitterOutputParams,
        LegacyProvidedSplitterOutputSplitsItemParams,
        LegacySplitterAdvancedOptionsParams,
        LegacySplitterConfigParams,
        LegacySplitterOutputParams,
        LegacySplitterOutputSplitsItemParams,
        MergeExtractResultMergedExtractorsItemParams,
        MergeExtractResultParams,
        MergeExtractStepRunParams,
        MergeExtractStepRunStepParams,
        PageRangesItemParams,
        PageRangesParams,
        ParentSplitParams,
        ParseConfigAdvancedOptionsParams,
        ParseConfigAdvancedOptionsReturnOcrParams,
        ParseConfigBlockOptionsFiguresParams,
        ParseConfigBlockOptionsParams,
        ParseConfigBlockOptionsTablesAgenticParams,
        ParseConfigBlockOptionsTablesParams,
        ParseConfigBlockOptionsTextAgenticParams,
        ParseConfigBlockOptionsTextParams,
        ParseConfigChunkingStrategyOptionsParams,
        ParseConfigChunkingStrategyParams,
        ParseConfigParams,
        ParseRequestFileParams,
        ParseResultParams,
        ParseRunFailedWebhookEventParams,
        ParseRunMetricsParams,
        ParseRunOutputOcrParams,
        ParseRunOutputOcrWordsItemParams,
        ParseRunOutputParams,
        ParseRunParams,
        ParseRunProcessedWebhookEventParams,
        ParseRunStatusParams,
        ParseStepRunParams,
        ParseStepRunStepParams,
        PolygonParams,
        ProvidedClassifyOutputParams,
        ProvidedExtractOutputParams,
        ProvidedProcessorOutputParams,
        ProvidedSplitOutputParams,
        ProvidedSplitOutputSplitsItemParams,
        RuleValidationResultParams,
        RuleValidationResultRulesItemParams,
        RuleValidationStepRunParams,
        RuleValidationStepRunStepParams,
        RunUsageParams,
        SplitAdvancedOptionsParams,
        SplitConfigParams,
        SplitOutputParams,
        SplitOutputSplitsItemParams,
        SplitRequestFileParams,
        SplitRequestSplitterParams,
        SplitResultParams,
        SplitRunFailedWebhookEventParams,
        SplitRunParams,
        SplitRunProcessedWebhookEventParams,
        SplitRunSummaryParams,
        SplitStepRunParams,
        SplitStepRunStepParams,
        SplitterCreatedWebhookEventParams,
        SplitterDeletedWebhookEventParams,
        SplitterDraftUpdatedWebhookEventParams,
        SplitterParams,
        SplitterSummaryParams,
        SplitterUpdatedWebhookEventParams,
        SplitterVersionParams,
        SplitterVersionPublishedWebhookEventParams,
        SplitterVersionSummaryParams,
        StepRunBaseParams,
        StepRunParams,
        TableCellDetailsParams,
        TableDetailsParams,
        TooManyRequestsErrorBodyParams,
        WebhookEventParams,
        WebhookEvent_ClassifierCreatedParams,
        WebhookEvent_ClassifierDeletedParams,
        WebhookEvent_ClassifierDraftUpdatedParams,
        WebhookEvent_ClassifierUpdatedParams,
        WebhookEvent_ClassifierVersionPublishedParams,
        WebhookEvent_ClassifyRunFailedParams,
        WebhookEvent_ClassifyRunProcessedParams,
        WebhookEvent_EditRunFailedParams,
        WebhookEvent_EditRunProcessedParams,
        WebhookEvent_ExtractRunFailedParams,
        WebhookEvent_ExtractRunProcessedParams,
        WebhookEvent_ExtractorCreatedParams,
        WebhookEvent_ExtractorDeletedParams,
        WebhookEvent_ExtractorDraftUpdatedParams,
        WebhookEvent_ExtractorUpdatedParams,
        WebhookEvent_ExtractorVersionPublishedParams,
        WebhookEvent_ParseRunFailedParams,
        WebhookEvent_ParseRunProcessedParams,
        WebhookEvent_SplitRunFailedParams,
        WebhookEvent_SplitRunProcessedParams,
        WebhookEvent_SplitterCreatedParams,
        WebhookEvent_SplitterDeletedParams,
        WebhookEvent_SplitterDraftUpdatedParams,
        WebhookEvent_SplitterUpdatedParams,
        WebhookEvent_SplitterVersionPublishedParams,
        WebhookEvent_WorkflowCreatedParams,
        WebhookEvent_WorkflowDeletedParams,
        WebhookEvent_WorkflowDeployedParams,
        WebhookEvent_WorkflowRunCancelledParams,
        WebhookEvent_WorkflowRunCompletedParams,
        WebhookEvent_WorkflowRunFailedParams,
        WebhookEvent_WorkflowRunNeedsReviewParams,
        WebhookEvent_WorkflowRunRejectedParams,
        WebhookEvent_WorkflowRunStepRunProcessedParams,
        WorkflowCreatedWebhookEventParams,
        WorkflowDeletedWebhookEventParams,
        WorkflowDeployedWebhookEventParams,
        WorkflowParams,
        WorkflowReferenceParams,
        WorkflowRunCancelledWebhookEventParams,
        WorkflowRunCompletedWebhookEventParams,
        WorkflowRunFailedWebhookEventParams,
        WorkflowRunNeedsReviewWebhookEventParams,
        WorkflowRunParams,
        WorkflowRunRejectedWebhookEventParams,
        WorkflowRunStepRunProcessedWebhookEventParams,
        WorkflowRunSummaryParams,
        WorkflowStepBaseParams,
        WorkflowSummaryParams,
        WorkflowVersionParams,
        WorkflowVersionSummaryParams,
    )
    from .split_runs import (
        SplitRunsCreateRequestFile,
        SplitRunsCreateRequestFileParams,
        SplitRunsCreateRequestSplitter,
        SplitRunsCreateRequestSplitterParams,
        SplitRunsDeleteResponse,
        SplitRunsDeleteResponseParams,
        SplitRunsListResponse,
        SplitRunsListResponseParams,
    )
    from .splitter_versions import SplitterVersionsListResponse, SplitterVersionsListResponseParams
    from .splitters import SplittersListResponse, SplittersListResponseParams
    from .version import __version__
    from .workflow_runs import (
        WorkflowRunsCreateBatchRequestInputsItem,
        WorkflowRunsCreateBatchRequestInputsItemFile,
        WorkflowRunsCreateBatchRequestInputsItemFileParams,
        WorkflowRunsCreateBatchRequestInputsItemParams,
        WorkflowRunsCreateBatchResponse,
        WorkflowRunsCreateBatchResponseParams,
        WorkflowRunsCreateRequestFile,
        WorkflowRunsCreateRequestFileParams,
        WorkflowRunsCreateRequestOutputsItem,
        WorkflowRunsCreateRequestOutputsItemParams,
        WorkflowRunsDeleteResponse,
        WorkflowRunsDeleteResponseParams,
        WorkflowRunsListResponse,
        WorkflowRunsListResponseParams,
    )
_dynamic_imports: typing.Dict[str, str] = {
    "ApiError": ".types",
    "ApiErrorParams": ".requests",
    "ApiVersionEnum": ".types",
    "ArrayStrategy": ".types",
    "ArrayStrategyParams": ".requests",
    "ArrayStrategyType": ".types",
    "AsyncExtend": ".wrapper",
    "BadRequestError": ".errors",
    "BatchProcessorRun": ".types",
    "BatchProcessorRunGetResponse": ".batch_processor_run",
    "BatchProcessorRunGetResponseParams": ".batch_processor_run",
    "BatchProcessorRunMetrics": ".types",
    "BatchProcessorRunMetricsParams": ".requests",
    "BatchProcessorRunOptions": ".types",
    "BatchProcessorRunOptionsParams": ".requests",
    "BatchProcessorRunParams": ".requests",
    "BatchProcessorRunSource": ".types",
    "BatchProcessorRunStatus": ".types",
    "BatchRun": ".types",
    "BatchRunEntity": ".types",
    "BatchRunEntityParams": ".requests",
    "BatchRunEntityVersion": ".types",
    "BatchRunEntityVersionParams": ".requests",
    "BatchRunEntityVersion_ClassifierVersion": ".types",
    "BatchRunEntityVersion_ClassifierVersionParams": ".requests",
    "BatchRunEntityVersion_ExtractorVersion": ".types",
    "BatchRunEntityVersion_ExtractorVersionParams": ".requests",
    "BatchRunEntityVersion_SplitterVersion": ".types",
    "BatchRunEntityVersion_SplitterVersionParams": ".requests",
    "BatchRunEntity_Classifier": ".types",
    "BatchRunEntity_ClassifierParams": ".requests",
    "BatchRunEntity_Extractor": ".types",
    "BatchRunEntity_ExtractorParams": ".requests",
    "BatchRunEntity_Splitter": ".types",
    "BatchRunEntity_SplitterParams": ".requests",
    "BatchRunMetrics": ".types",
    "BatchRunMetricsParams": ".requests",
    "BatchRunParams": ".requests",
    "BatchRunStatus": ".types",
    "Block": ".types",
    "BlockDetails": ".types",
    "BlockDetailsParams": ".requests",
    "BlockMetadata": ".types",
    "BlockMetadataPage": ".types",
    "BlockMetadataPageParams": ".requests",
    "BlockMetadataParams": ".requests",
    "BlockParams": ".requests",
    "BlockPolygonItem": ".types",
    "BlockPolygonItemParams": ".requests",
    "BlockType": ".types",
    "BoundingBox": ".types",
    "BoundingBoxParams": ".requests",
    "Chunk": ".types",
    "ChunkMetadata": ".types",
    "ChunkMetadataPageRange": ".types",
    "ChunkMetadataPageRangeParams": ".requests",
    "ChunkMetadataParams": ".requests",
    "ChunkParams": ".requests",
    "ChunkType": ".types",
    "Citation": ".types",
    "CitationPage": ".types",
    "CitationPageParams": ".requests",
    "CitationParams": ".requests",
    "Classification": ".types",
    "ClassificationParams": ".requests",
    "Classifications": ".types",
    "ClassificationsParams": ".requests",
    "Classifier": ".types",
    "ClassifierCreatedWebhookEvent": ".types",
    "ClassifierCreatedWebhookEventParams": ".requests",
    "ClassifierDeletedWebhookEvent": ".types",
    "ClassifierDeletedWebhookEventParams": ".requests",
    "ClassifierDraftUpdatedWebhookEvent": ".types",
    "ClassifierDraftUpdatedWebhookEventParams": ".requests",
    "ClassifierParams": ".requests",
    "ClassifierSummary": ".types",
    "ClassifierSummaryParams": ".requests",
    "ClassifierUpdatedWebhookEvent": ".types",
    "ClassifierUpdatedWebhookEventParams": ".requests",
    "ClassifierVersion": ".types",
    "ClassifierVersionParams": ".requests",
    "ClassifierVersionPublishedWebhookEvent": ".types",
    "ClassifierVersionPublishedWebhookEventParams": ".requests",
    "ClassifierVersionSummary": ".types",
    "ClassifierVersionSummaryParams": ".requests",
    "ClassifierVersionsListResponse": ".classifier_versions",
    "ClassifierVersionsListResponseParams": ".classifier_versions",
    "ClassifiersListResponse": ".classifiers",
    "ClassifiersListResponseParams": ".classifiers",
    "ClassifyAdvancedOptions": ".types",
    "ClassifyAdvancedOptionsContext": ".types",
    "ClassifyAdvancedOptionsParams": ".requests",
    "ClassifyConfig": ".types",
    "ClassifyConfigBaseProcessor": ".types",
    "ClassifyConfigParams": ".requests",
    "ClassifyOutput": ".types",
    "ClassifyOutputParams": ".requests",
    "ClassifyRequestClassifier": ".types",
    "ClassifyRequestClassifierParams": ".requests",
    "ClassifyRequestFile": ".types",
    "ClassifyRequestFileParams": ".requests",
    "ClassifyResult": ".types",
    "ClassifyResultParams": ".requests",
    "ClassifyRun": ".types",
    "ClassifyRunFailedWebhookEvent": ".types",
    "ClassifyRunFailedWebhookEventParams": ".requests",
    "ClassifyRunParams": ".requests",
    "ClassifyRunProcessedWebhookEvent": ".types",
    "ClassifyRunProcessedWebhookEventParams": ".requests",
    "ClassifyRunSummary": ".types",
    "ClassifyRunSummaryParams": ".requests",
    "ClassifyRunsCreateRequestClassifier": ".classify_runs",
    "ClassifyRunsCreateRequestClassifierParams": ".classify_runs",
    "ClassifyRunsCreateRequestFile": ".classify_runs",
    "ClassifyRunsCreateRequestFileParams": ".classify_runs",
    "ClassifyRunsDeleteResponse": ".classify_runs",
    "ClassifyRunsDeleteResponseParams": ".classify_runs",
    "ClassifyRunsListResponse": ".classify_runs",
    "ClassifyRunsListResponseParams": ".classify_runs",
    "ClassifyStepRun": ".types",
    "ClassifyStepRunParams": ".requests",
    "ClassifyStepRunStep": ".types",
    "ClassifyStepRunStepParams": ".requests",
    "ConditionalExtractResult": ".types",
    "ConditionalExtractResultParams": ".requests",
    "ConditionalExtractStepRun": ".types",
    "ConditionalExtractStepRunParams": ".requests",
    "ConditionalExtractStepRunStep": ".types",
    "ConditionalExtractStepRunStepParams": ".requests",
    "CreatedAt": ".types",
    "EditBoundingBox": ".types",
    "EditBoundingBoxParams": ".requests",
    "EditConfig": ".types",
    "EditConfigAdvancedOptions": ".types",
    "EditConfigAdvancedOptionsParams": ".requests",
    "EditConfigParams": ".requests",
    "EditJson": ".types",
    "EditJsonExtendEditFieldType": ".types",
    "EditJsonParams": ".requests",
    "EditObjectJson": ".types",
    "EditObjectJsonParams": ".requests",
    "EditRequestFile": ".types",
    "EditRequestFileParams": ".requests",
    "EditRootJson": ".types",
    "EditRootJsonParams": ".requests",
    "EditRun": ".types",
    "EditRunFailedWebhookEvent": ".types",
    "EditRunFailedWebhookEventParams": ".requests",
    "EditRunMetrics": ".types",
    "EditRunMetricsParams": ".requests",
    "EditRunOutput": ".types",
    "EditRunOutputEditedFile": ".types",
    "EditRunOutputEditedFileParams": ".requests",
    "EditRunOutputParams": ".requests",
    "EditRunParams": ".requests",
    "EditRunProcessedWebhookEvent": ".types",
    "EditRunProcessedWebhookEventParams": ".requests",
    "EditRunStatus": ".types",
    "EditRunsCreateRequestFile": ".edit_runs",
    "EditRunsCreateRequestFileParams": ".edit_runs",
    "EditRunsDeleteResponse": ".edit_runs",
    "EditRunsDeleteResponseParams": ".edit_runs",
    "EditTextOptions": ".types",
    "EditTextOptionsParams": ".requests",
    "EmptyBlockDetails": ".types",
    "Enum": ".types",
    "EnumOption": ".types",
    "EnumOptionParams": ".requests",
    "EnumParams": ".requests",
    "EvaluationSet": ".types",
    "EvaluationSetEntity": ".types",
    "EvaluationSetEntityParams": ".requests",
    "EvaluationSetEntity_Classifier": ".types",
    "EvaluationSetEntity_ClassifierParams": ".requests",
    "EvaluationSetEntity_Extractor": ".types",
    "EvaluationSetEntity_ExtractorParams": ".requests",
    "EvaluationSetEntity_Splitter": ".types",
    "EvaluationSetEntity_SplitterParams": ".requests",
    "EvaluationSetItem": ".types",
    "EvaluationSetItemParams": ".requests",
    "EvaluationSetItemSummary": ".types",
    "EvaluationSetItemSummaryParams": ".requests",
    "EvaluationSetItemsCreateRequestItemsItem": ".evaluation_set_items",
    "EvaluationSetItemsCreateRequestItemsItemParams": ".evaluation_set_items",
    "EvaluationSetItemsCreateResponse": ".evaluation_set_items",
    "EvaluationSetItemsCreateResponseParams": ".evaluation_set_items",
    "EvaluationSetItemsDeleteResponse": ".evaluation_set_items",
    "EvaluationSetItemsDeleteResponseParams": ".evaluation_set_items",
    "EvaluationSetItemsListResponse": ".evaluation_set_items",
    "EvaluationSetItemsListResponseParams": ".evaluation_set_items",
    "EvaluationSetParams": ".requests",
    "EvaluationSetRun": ".types",
    "EvaluationSetRunEntity": ".types",
    "EvaluationSetRunEntityParams": ".requests",
    "EvaluationSetRunEntityVersion": ".types",
    "EvaluationSetRunEntityVersionParams": ".requests",
    "EvaluationSetRunEntityVersion_ClassifierVersion": ".types",
    "EvaluationSetRunEntityVersion_ClassifierVersionParams": ".requests",
    "EvaluationSetRunEntityVersion_ExtractorVersion": ".types",
    "EvaluationSetRunEntityVersion_ExtractorVersionParams": ".requests",
    "EvaluationSetRunEntityVersion_SplitterVersion": ".types",
    "EvaluationSetRunEntityVersion_SplitterVersionParams": ".requests",
    "EvaluationSetRunEntity_Classifier": ".types",
    "EvaluationSetRunEntity_ClassifierParams": ".requests",
    "EvaluationSetRunEntity_Extractor": ".types",
    "EvaluationSetRunEntity_ExtractorParams": ".requests",
    "EvaluationSetRunEntity_Splitter": ".types",
    "EvaluationSetRunEntity_SplitterParams": ".requests",
    "EvaluationSetRunMetrics": ".types",
    "EvaluationSetRunMetricsParams": ".requests",
    "EvaluationSetRunOptions": ".types",
    "EvaluationSetRunOptionsParams": ".requests",
    "EvaluationSetRunParams": ".requests",
    "EvaluationSetsListResponse": ".evaluation_sets",
    "EvaluationSetsListResponseParams": ".evaluation_sets",
    "ExcelSheetRange": ".types",
    "ExcelSheetRangeParams": ".requests",
    "Extend": ".wrapper",
    "Webhooks": ".wrapper",
    "PollingOptions": ".wrapper",
    "PollingTimeoutError": ".wrapper",
    "ExtendEnvironment": ".environment",
    "ExternalDataValidationResult": ".types",
    "ExternalDataValidationResultParams": ".requests",
    "ExternalDataValidationResultResponse": ".types",
    "ExternalDataValidationResultResponseParams": ".requests",
    "ExternalDataValidationStepRun": ".types",
    "ExternalDataValidationStepRunParams": ".requests",
    "ExternalDataValidationStepRunStep": ".types",
    "ExternalDataValidationStepRunStepParams": ".requests",
    "ExtractAdvancedOptions": ".types",
    "ExtractAdvancedOptionsArrayCitationStrategy": ".types",
    "ExtractAdvancedOptionsExcelSheetSelectionStrategy": ".types",
    "ExtractAdvancedOptionsParams": ".requests",
    "ExtractAdvancedOptionsReviewAgent": ".types",
    "ExtractAdvancedOptionsReviewAgentParams": ".requests",
    "ExtractChunkingOptions": ".types",
    "ExtractChunkingOptionsChunkSelectionStrategy": ".types",
    "ExtractChunkingOptionsChunkingStrategy": ".types",
    "ExtractChunkingOptionsParams": ".requests",
    "ExtractConfig": ".types",
    "ExtractConfigJson": ".types",
    "ExtractConfigJsonBaseProcessor": ".types",
    "ExtractConfigJsonParams": ".requests",
    "ExtractConfigLegacy": ".types",
    "ExtractConfigLegacyBaseProcessor": ".types",
    "ExtractConfigLegacyParams": ".requests",
    "ExtractConfigParams": ".requests",
    "ExtractOutput": ".types",
    "ExtractOutputEdits": ".types",
    "ExtractOutputEditsParams": ".requests",
    "ExtractOutputJson": ".types",
    "ExtractOutputJsonParams": ".requests",
    "ExtractOutputLegacy": ".types",
    "ExtractOutputLegacyParams": ".requests",
    "ExtractOutputMetadata": ".types",
    "ExtractOutputMetadataParams": ".requests",
    "ExtractOutputMetadataValue": ".types",
    "ExtractOutputMetadataValueParams": ".requests",
    "ExtractOutputParams": ".requests",
    "ExtractRequestExtractor": ".types",
    "ExtractRequestExtractorParams": ".requests",
    "ExtractRequestFile": ".types",
    "ExtractRequestFileParams": ".requests",
    "ExtractResult": ".types",
    "ExtractResultParams": ".requests",
    "ExtractRun": ".types",
    "ExtractRunFailedWebhookEvent": ".types",
    "ExtractRunFailedWebhookEventParams": ".requests",
    "ExtractRunParams": ".requests",
    "ExtractRunProcessedWebhookEvent": ".types",
    "ExtractRunProcessedWebhookEventParams": ".requests",
    "ExtractRunSummary": ".types",
    "ExtractRunSummaryParams": ".requests",
    "ExtractRunsCreateRequestExtractor": ".extract_runs",
    "ExtractRunsCreateRequestExtractorParams": ".extract_runs",
    "ExtractRunsCreateRequestFile": ".extract_runs",
    "ExtractRunsCreateRequestFileParams": ".extract_runs",
    "ExtractRunsDeleteResponse": ".extract_runs",
    "ExtractRunsDeleteResponseParams": ".extract_runs",
    "ExtractRunsListResponse": ".extract_runs",
    "ExtractRunsListResponseParams": ".extract_runs",
    "ExtractStepRun": ".types",
    "ExtractStepRunParams": ".requests",
    "ExtractStepRunStep": ".types",
    "ExtractStepRunStepParams": ".requests",
    "ExtractionField": ".types",
    "ExtractionFieldParams": ".requests",
    "ExtractionFieldResult": ".types",
    "ExtractionFieldResultParams": ".requests",
    "ExtractionFieldResultReference": ".types",
    "ExtractionFieldResultReferenceBoundingBoxesItem": ".types",
    "ExtractionFieldResultReferenceBoundingBoxesItemParams": ".requests",
    "ExtractionFieldResultReferenceParams": ".requests",
    "ExtractionFieldResultType": ".types",
    "ExtractionFieldType": ".types",
    "Extractor": ".types",
    "ExtractorCreatedWebhookEvent": ".types",
    "ExtractorCreatedWebhookEventParams": ".requests",
    "ExtractorDeletedWebhookEvent": ".types",
    "ExtractorDeletedWebhookEventParams": ".requests",
    "ExtractorDraftUpdatedWebhookEvent": ".types",
    "ExtractorDraftUpdatedWebhookEventParams": ".requests",
    "ExtractorParams": ".requests",
    "ExtractorSummary": ".types",
    "ExtractorSummaryParams": ".requests",
    "ExtractorUpdatedWebhookEvent": ".types",
    "ExtractorUpdatedWebhookEventParams": ".requests",
    "ExtractorVersion": ".types",
    "ExtractorVersionParams": ".requests",
    "ExtractorVersionPublishedWebhookEvent": ".types",
    "ExtractorVersionPublishedWebhookEventParams": ".requests",
    "ExtractorVersionSummary": ".types",
    "ExtractorVersionSummaryParams": ".requests",
    "ExtractorVersionsListResponse": ".extractor_versions",
    "ExtractorVersionsListResponseParams": ".extractor_versions",
    "ExtractorsListResponse": ".extractors",
    "ExtractorsListResponseParams": ".extractors",
    "FigureDetails": ".types",
    "FigureDetailsFigureType": ".types",
    "FigureDetailsParams": ".requests",
    "File": ".types",
    "FileContents": ".types",
    "FileContentsPagesItem": ".types",
    "FileContentsPagesItemParams": ".requests",
    "FileContentsParams": ".requests",
    "FileContentsSectionsItem": ".types",
    "FileContentsSectionsItemParams": ".requests",
    "FileContentsSheetsItem": ".types",
    "FileContentsSheetsItemParams": ".requests",
    "FileFromId": ".types",
    "FileFromIdParams": ".requests",
    "FileFromText": ".types",
    "FileFromTextParams": ".requests",
    "FileFromUrl": ".types",
    "FileFromUrlParams": ".requests",
    "FileMetadata": ".types",
    "FileMetadataParams": ".requests",
    "FileParams": ".requests",
    "FileSummary": ".types",
    "FileSummaryParams": ".requests",
    "FileType": ".types",
    "FilesDeleteResponse": ".files",
    "FilesDeleteResponseParams": ".files",
    "FilesListResponse": ".files",
    "FilesListResponseParams": ".files",
    "ForbiddenError": ".errors",
    "Insight": ".types",
    "InsightParams": ".requests",
    "InternalServerError": ".errors",
    "JsonObject": ".types",
    "LegacyBatchProcessorRun": ".types",
    "LegacyBatchProcessorRunMetrics": ".types",
    "LegacyBatchProcessorRunMetricsParams": ".requests",
    "LegacyBatchProcessorRunOptions": ".types",
    "LegacyBatchProcessorRunOptionsParams": ".requests",
    "LegacyBatchProcessorRunParams": ".requests",
    "LegacyBatchProcessorRunSource": ".types",
    "LegacyBatchProcessorRunStatus": ".types",
    "LegacyClassification": ".types",
    "LegacyClassificationAdvancedOptions": ".types",
    "LegacyClassificationAdvancedOptionsContext": ".types",
    "LegacyClassificationAdvancedOptionsParams": ".requests",
    "LegacyClassificationConfig": ".types",
    "LegacyClassificationConfigBaseProcessor": ".types",
    "LegacyClassificationConfigParams": ".requests",
    "LegacyClassificationParams": ".requests",
    "LegacyClassifierOutput": ".types",
    "LegacyClassifierOutputParams": ".requests",
    "LegacyDocumentProcessorRunCredits": ".types",
    "LegacyDocumentProcessorRunCreditsParams": ".requests",
    "LegacyError": ".types",
    "LegacyErrorParams": ".requests",
    "LegacyExtendError": ".types",
    "LegacyExtendErrorParams": ".requests",
    "LegacyExtractChunkingOptions": ".types",
    "LegacyExtractChunkingOptionsChunkSelectionStrategy": ".types",
    "LegacyExtractChunkingOptionsChunkingStrategy": ".types",
    "LegacyExtractChunkingOptionsParams": ".requests",
    "LegacyExtractionAdvancedOptions": ".types",
    "LegacyExtractionAdvancedOptionsArrayCitationStrategy": ".types",
    "LegacyExtractionAdvancedOptionsExcelSheetSelectionStrategy": ".types",
    "LegacyExtractionAdvancedOptionsParams": ".requests",
    "LegacyExtractionAdvancedOptionsReviewAgent": ".types",
    "LegacyExtractionAdvancedOptionsReviewAgentParams": ".requests",
    "LegacyExtractionConfig": ".types",
    "LegacyExtractionConfigBaseProcessor": ".types",
    "LegacyExtractionConfigParams": ".requests",
    "LegacyExtractionField": ".types",
    "LegacyExtractionFieldParams": ".requests",
    "LegacyExtractionFieldResult": ".types",
    "LegacyExtractionFieldResultParams": ".requests",
    "LegacyExtractionFieldResultType": ".types",
    "LegacyExtractionFieldType": ".types",
    "LegacyExtractionOutput": ".types",
    "LegacyExtractionOutputEdits": ".types",
    "LegacyExtractionOutputEditsParams": ".requests",
    "LegacyExtractionOutputParams": ".requests",
    "LegacyFieldsArrayOutput": ".types",
    "LegacyFieldsArrayOutputParams": ".requests",
    "LegacyJsonObject": ".types",
    "LegacyJsonOutput": ".types",
    "LegacyJsonOutputMetadataValue": ".types",
    "LegacyJsonOutputMetadataValueCitationsItem": ".types",
    "LegacyJsonOutputMetadataValueCitationsItemParams": ".requests",
    "LegacyJsonOutputMetadataValueCitationsItemPolygonItem": ".types",
    "LegacyJsonOutputMetadataValueCitationsItemPolygonItemParams": ".requests",
    "LegacyJsonOutputMetadataValueParams": ".requests",
    "LegacyJsonOutputParams": ".requests",
    "LegacyListProcessorsProcessor": ".types",
    "LegacyListProcessorsProcessorParams": ".requests",
    "LegacyListProcessorsProcessorVersion": ".types",
    "LegacyListProcessorsProcessorVersionParams": ".requests",
    "LegacyListProcessorsResponse": ".types",
    "LegacyListProcessorsResponseParams": ".requests",
    "LegacyMaxPageSize": ".types",
    "LegacyNextPageToken": ".types",
    "LegacyProcessor": ".types",
    "LegacyProcessorId": ".types",
    "LegacyProcessorOutput": ".types",
    "LegacyProcessorOutputParams": ".requests",
    "LegacyProcessorParams": ".requests",
    "LegacyProcessorRun": ".types",
    "LegacyProcessorRunConfig": ".types",
    "LegacyProcessorRunConfigParams": ".requests",
    "LegacyProcessorRunConfig_Classify": ".types",
    "LegacyProcessorRunConfig_ClassifyParams": ".requests",
    "LegacyProcessorRunConfig_Extract": ".types",
    "LegacyProcessorRunConfig_ExtractParams": ".requests",
    "LegacyProcessorRunConfig_Splitter": ".types",
    "LegacyProcessorRunConfig_SplitterParams": ".requests",
    "LegacyProcessorRunFileInput": ".types",
    "LegacyProcessorRunFileInputParams": ".requests",
    "LegacyProcessorRunMergedProcessorsItem": ".types",
    "LegacyProcessorRunMergedProcessorsItemParams": ".requests",
    "LegacyProcessorRunParams": ".requests",
    "LegacyProcessorRunSummary": ".types",
    "LegacyProcessorRunSummaryParams": ".requests",
    "LegacyProcessorRunSummaryType": ".types",
    "LegacyProcessorRunType": ".types",
    "LegacyProcessorStatus": ".types",
    "LegacyProcessorType": ".types",
    "LegacyProcessorVersion": ".types",
    "LegacyProcessorVersionConfig": ".types",
    "LegacyProcessorVersionConfigParams": ".requests",
    "LegacyProcessorVersionConfig_Classify": ".types",
    "LegacyProcessorVersionConfig_ClassifyParams": ".requests",
    "LegacyProcessorVersionConfig_Extract": ".types",
    "LegacyProcessorVersionConfig_ExtractParams": ".requests",
    "LegacyProcessorVersionConfig_Splitter": ".types",
    "LegacyProcessorVersionConfig_SplitterParams": ".requests",
    "LegacyProcessorVersionParams": ".requests",
    "LegacyProvidedClassifierOutput": ".types",
    "LegacyProvidedClassifierOutputParams": ".requests",
    "LegacyProvidedExtractionFieldResult": ".types",
    "LegacyProvidedExtractionFieldResultParams": ".requests",
    "LegacyProvidedExtractionFieldResultType": ".types",
    "LegacyProvidedExtractionOutput": ".types",
    "LegacyProvidedExtractionOutputParams": ".requests",
    "LegacyProvidedFieldsArrayOutput": ".types",
    "LegacyProvidedFieldsArrayOutputParams": ".requests",
    "LegacyProvidedJsonOutput": ".types",
    "LegacyProvidedJsonOutputParams": ".requests",
    "LegacyProvidedProcessorOutput": ".types",
    "LegacyProvidedProcessorOutputParams": ".requests",
    "LegacyProvidedSplitterOutput": ".types",
    "LegacyProvidedSplitterOutputParams": ".requests",
    "LegacyProvidedSplitterOutputSplitsItem": ".types",
    "LegacyProvidedSplitterOutputSplitsItemParams": ".requests",
    "LegacySortByEnum": ".types",
    "LegacySortDirEnum": ".types",
    "LegacySplitterAdvancedOptions": ".types",
    "LegacySplitterAdvancedOptionsParams": ".requests",
    "LegacySplitterAdvancedOptionsSplitMethod": ".types",
    "LegacySplitterConfig": ".types",
    "LegacySplitterConfigBaseProcessor": ".types",
    "LegacySplitterConfigParams": ".requests",
    "LegacySplitterOutput": ".types",
    "LegacySplitterOutputParams": ".requests",
    "LegacySplitterOutputSplitsItem": ".types",
    "LegacySplitterOutputSplitsItemParams": ".requests",
    "MaxPageSize": ".types",
    "MergeExtractResult": ".types",
    "MergeExtractResultMergedExtractorsItem": ".types",
    "MergeExtractResultMergedExtractorsItemParams": ".requests",
    "MergeExtractResultParams": ".requests",
    "MergeExtractStepRun": ".types",
    "MergeExtractStepRunParams": ".requests",
    "MergeExtractStepRunStep": ".types",
    "MergeExtractStepRunStepParams": ".requests",
    "NextPageToken": ".types",
    "NotFoundError": ".errors",
    "PageRanges": ".types",
    "PageRangesItem": ".types",
    "PageRangesItemParams": ".requests",
    "PageRangesParams": ".requests",
    "ParentSplit": ".types",
    "ParentSplitParams": ".requests",
    "ParseConfig": ".types",
    "ParseConfigAdvancedOptions": ".types",
    "ParseConfigAdvancedOptionsParams": ".requests",
    "ParseConfigAdvancedOptionsReturnOcr": ".types",
    "ParseConfigAdvancedOptionsReturnOcrParams": ".requests",
    "ParseConfigBlockOptions": ".types",
    "ParseConfigBlockOptionsFigures": ".types",
    "ParseConfigBlockOptionsFiguresParams": ".requests",
    "ParseConfigBlockOptionsParams": ".requests",
    "ParseConfigBlockOptionsTables": ".types",
    "ParseConfigBlockOptionsTablesAgentic": ".types",
    "ParseConfigBlockOptionsTablesAgenticParams": ".requests",
    "ParseConfigBlockOptionsTablesParams": ".requests",
    "ParseConfigBlockOptionsTablesTargetFormat": ".types",
    "ParseConfigBlockOptionsText": ".types",
    "ParseConfigBlockOptionsTextAgentic": ".types",
    "ParseConfigBlockOptionsTextAgenticParams": ".requests",
    "ParseConfigBlockOptionsTextParams": ".requests",
    "ParseConfigChunkingStrategy": ".types",
    "ParseConfigChunkingStrategyOptions": ".types",
    "ParseConfigChunkingStrategyOptionsParams": ".requests",
    "ParseConfigChunkingStrategyParams": ".requests",
    "ParseConfigChunkingStrategyType": ".types",
    "ParseConfigEngine": ".types",
    "ParseConfigParams": ".requests",
    "ParseConfigTarget": ".types",
    "ParseRequestFile": ".types",
    "ParseRequestFileParams": ".requests",
    "ParseRequestResponseType": ".types",
    "ParseResult": ".types",
    "ParseResultParams": ".requests",
    "ParseRun": ".types",
    "ParseRunFailedWebhookEvent": ".types",
    "ParseRunFailedWebhookEventParams": ".requests",
    "ParseRunMetrics": ".types",
    "ParseRunMetricsParams": ".requests",
    "ParseRunOutput": ".types",
    "ParseRunOutputOcr": ".types",
    "ParseRunOutputOcrParams": ".requests",
    "ParseRunOutputOcrWordsItem": ".types",
    "ParseRunOutputOcrWordsItemParams": ".requests",
    "ParseRunOutputParams": ".requests",
    "ParseRunParams": ".requests",
    "ParseRunProcessedWebhookEvent": ".types",
    "ParseRunProcessedWebhookEventParams": ".requests",
    "ParseRunStatus": ".types",
    "ParseRunStatusEnum": ".types",
    "ParseRunStatusParams": ".requests",
    "ParseRunStatusStatus": ".types",
    "ParseRunsCreateRequestFile": ".parse_runs",
    "ParseRunsCreateRequestFileParams": ".parse_runs",
    "ParseRunsDeleteResponse": ".parse_runs",
    "ParseRunsDeleteResponseParams": ".parse_runs",
    "ParseRunsRetrieveRequestResponseType": ".parse_runs",
    "ParseStepRun": ".types",
    "ParseStepRunParams": ".requests",
    "ParseStepRunStep": ".types",
    "ParseStepRunStepParams": ".requests",
    "PaymentRequiredError": ".errors",
    "Polygon": ".types",
    "PolygonParams": ".requests",
    "ProcessorCreateRequestConfig": ".processor",
    "ProcessorCreateRequestConfigParams": ".processor",
    "ProcessorCreateRequestConfig_Classify": ".processor",
    "ProcessorCreateRequestConfig_ClassifyParams": ".processor",
    "ProcessorCreateRequestConfig_Extract": ".processor",
    "ProcessorCreateRequestConfig_ExtractParams": ".processor",
    "ProcessorCreateRequestConfig_Splitter": ".processor",
    "ProcessorCreateRequestConfig_SplitterParams": ".processor",
    "ProcessorCreateResponse": ".processor",
    "ProcessorCreateResponseParams": ".processor",
    "ProcessorListRequestSortBy": ".processor",
    "ProcessorListRequestSortDir": ".processor",
    "ProcessorRunCancelResponse": ".processor_run",
    "ProcessorRunCancelResponseParams": ".processor_run",
    "ProcessorRunCreateRequestConfig": ".processor_run",
    "ProcessorRunCreateRequestConfigParams": ".processor_run",
    "ProcessorRunCreateRequestConfig_Classify": ".processor_run",
    "ProcessorRunCreateRequestConfig_ClassifyParams": ".processor_run",
    "ProcessorRunCreateRequestConfig_Extract": ".processor_run",
    "ProcessorRunCreateRequestConfig_ExtractParams": ".processor_run",
    "ProcessorRunCreateRequestConfig_Splitter": ".processor_run",
    "ProcessorRunCreateRequestConfig_SplitterParams": ".processor_run",
    "ProcessorRunCreateResponse": ".processor_run",
    "ProcessorRunCreateResponseParams": ".processor_run",
    "ProcessorRunDeleteResponse": ".processor_run",
    "ProcessorRunDeleteResponseParams": ".processor_run",
    "ProcessorRunGetResponse": ".processor_run",
    "ProcessorRunGetResponseParams": ".processor_run",
    "ProcessorRunListRequestSource": ".processor_run",
    "ProcessorRunListResponse": ".processor_run",
    "ProcessorRunListResponseParams": ".processor_run",
    "ProcessorRunStatus": ".types",
    "ProcessorUpdateRequestConfig": ".processor",
    "ProcessorUpdateRequestConfigParams": ".processor",
    "ProcessorUpdateRequestConfig_Classify": ".processor",
    "ProcessorUpdateRequestConfig_ClassifyParams": ".processor",
    "ProcessorUpdateRequestConfig_Extract": ".processor",
    "ProcessorUpdateRequestConfig_ExtractParams": ".processor",
    "ProcessorUpdateRequestConfig_Splitter": ".processor",
    "ProcessorUpdateRequestConfig_SplitterParams": ".processor",
    "ProcessorUpdateResponse": ".processor",
    "ProcessorUpdateResponseParams": ".processor",
    "ProcessorVersionCreateRequestConfig": ".processor_version",
    "ProcessorVersionCreateRequestConfigParams": ".processor_version",
    "ProcessorVersionCreateRequestConfig_Classify": ".processor_version",
    "ProcessorVersionCreateRequestConfig_ClassifyParams": ".processor_version",
    "ProcessorVersionCreateRequestConfig_Extract": ".processor_version",
    "ProcessorVersionCreateRequestConfig_ExtractParams": ".processor_version",
    "ProcessorVersionCreateRequestConfig_Splitter": ".processor_version",
    "ProcessorVersionCreateRequestConfig_SplitterParams": ".processor_version",
    "ProcessorVersionCreateRequestReleaseType": ".processor_version",
    "ProcessorVersionCreateResponse": ".processor_version",
    "ProcessorVersionCreateResponseParams": ".processor_version",
    "ProcessorVersionGetResponse": ".processor_version",
    "ProcessorVersionGetResponseParams": ".processor_version",
    "ProcessorVersionListResponse": ".processor_version",
    "ProcessorVersionListResponseParams": ".processor_version",
    "ProcessorVersionString": ".types",
    "ProvidedClassifyOutput": ".types",
    "ProvidedClassifyOutputParams": ".requests",
    "ProvidedExtractOutput": ".types",
    "ProvidedExtractOutputParams": ".requests",
    "ProvidedProcessorOutput": ".types",
    "ProvidedProcessorOutputParams": ".requests",
    "ProvidedSplitOutput": ".types",
    "ProvidedSplitOutputParams": ".requests",
    "ProvidedSplitOutputSplitsItem": ".types",
    "ProvidedSplitOutputSplitsItemParams": ".requests",
    "ReleaseType": ".types",
    "RuleValidationResult": ".types",
    "RuleValidationResultParams": ".requests",
    "RuleValidationResultRulesItem": ".types",
    "RuleValidationResultRulesItemFailureReason": ".types",
    "RuleValidationResultRulesItemParams": ".requests",
    "RuleValidationStepRun": ".types",
    "RuleValidationStepRunParams": ".requests",
    "RuleValidationStepRunStep": ".types",
    "RuleValidationStepRunStepParams": ".requests",
    "RunMetadata": ".types",
    "RunPriority": ".types",
    "RunSecrets": ".types",
    "RunSource": ".types",
    "RunSourceId": ".types",
    "RunUsage": ".types",
    "RunUsageParams": ".requests",
    "SortBy": ".types",
    "SortDir": ".types",
    "SplitAdvancedOptions": ".types",
    "SplitAdvancedOptionsParams": ".requests",
    "SplitAdvancedOptionsSplitMethod": ".types",
    "SplitConfig": ".types",
    "SplitConfigBaseProcessor": ".types",
    "SplitConfigParams": ".requests",
    "SplitOutput": ".types",
    "SplitOutputParams": ".requests",
    "SplitOutputSplitsItem": ".types",
    "SplitOutputSplitsItemParams": ".requests",
    "SplitRequestFile": ".types",
    "SplitRequestFileParams": ".requests",
    "SplitRequestSplitter": ".types",
    "SplitRequestSplitterParams": ".requests",
    "SplitResult": ".types",
    "SplitResultParams": ".requests",
    "SplitRun": ".types",
    "SplitRunFailedWebhookEvent": ".types",
    "SplitRunFailedWebhookEventParams": ".requests",
    "SplitRunParams": ".requests",
    "SplitRunProcessedWebhookEvent": ".types",
    "SplitRunProcessedWebhookEventParams": ".requests",
    "SplitRunSummary": ".types",
    "SplitRunSummaryParams": ".requests",
    "SplitRunsCreateRequestFile": ".split_runs",
    "SplitRunsCreateRequestFileParams": ".split_runs",
    "SplitRunsCreateRequestSplitter": ".split_runs",
    "SplitRunsCreateRequestSplitterParams": ".split_runs",
    "SplitRunsDeleteResponse": ".split_runs",
    "SplitRunsDeleteResponseParams": ".split_runs",
    "SplitRunsListResponse": ".split_runs",
    "SplitRunsListResponseParams": ".split_runs",
    "SplitStepRun": ".types",
    "SplitStepRunParams": ".requests",
    "SplitStepRunStep": ".types",
    "SplitStepRunStepParams": ".requests",
    "Splitter": ".types",
    "SplitterCreatedWebhookEvent": ".types",
    "SplitterCreatedWebhookEventParams": ".requests",
    "SplitterDeletedWebhookEvent": ".types",
    "SplitterDeletedWebhookEventParams": ".requests",
    "SplitterDraftUpdatedWebhookEvent": ".types",
    "SplitterDraftUpdatedWebhookEventParams": ".requests",
    "SplitterParams": ".requests",
    "SplitterSummary": ".types",
    "SplitterSummaryParams": ".requests",
    "SplitterUpdatedWebhookEvent": ".types",
    "SplitterUpdatedWebhookEventParams": ".requests",
    "SplitterVersion": ".types",
    "SplitterVersionParams": ".requests",
    "SplitterVersionPublishedWebhookEvent": ".types",
    "SplitterVersionPublishedWebhookEventParams": ".requests",
    "SplitterVersionSummary": ".types",
    "SplitterVersionSummaryParams": ".requests",
    "SplitterVersionsListResponse": ".splitter_versions",
    "SplitterVersionsListResponseParams": ".splitter_versions",
    "SplittersListResponse": ".splitters",
    "SplittersListResponseParams": ".splitters",
    "StepRun": ".types",
    "StepRunBase": ".types",
    "StepRunBaseParams": ".requests",
    "StepRunBaseStatus": ".types",
    "StepRunParams": ".requests",
    "TableCellDetails": ".types",
    "TableCellDetailsParams": ".requests",
    "TableDetails": ".types",
    "TableDetailsParams": ".requests",
    "TooManyRequestsError": ".errors",
    "TooManyRequestsErrorBody": ".types",
    "TooManyRequestsErrorBodyParams": ".requests",
    "UnauthorizedError": ".errors",
    "UnprocessableEntityError": ".errors",
    "UpdatedAt": ".types",
    "VersionDescription": ".types",
    "WebhookEvent": ".types",
    "WebhookEventParams": ".requests",
    "WebhookEvent_ClassifierCreated": ".types",
    "WebhookEvent_ClassifierCreatedParams": ".requests",
    "WebhookEvent_ClassifierDeleted": ".types",
    "WebhookEvent_ClassifierDeletedParams": ".requests",
    "WebhookEvent_ClassifierDraftUpdated": ".types",
    "WebhookEvent_ClassifierDraftUpdatedParams": ".requests",
    "WebhookEvent_ClassifierUpdated": ".types",
    "WebhookEvent_ClassifierUpdatedParams": ".requests",
    "WebhookEvent_ClassifierVersionPublished": ".types",
    "WebhookEvent_ClassifierVersionPublishedParams": ".requests",
    "WebhookEvent_ClassifyRunFailed": ".types",
    "WebhookEvent_ClassifyRunFailedParams": ".requests",
    "WebhookEvent_ClassifyRunProcessed": ".types",
    "WebhookEvent_ClassifyRunProcessedParams": ".requests",
    "WebhookEvent_EditRunFailed": ".types",
    "WebhookEvent_EditRunFailedParams": ".requests",
    "WebhookEvent_EditRunProcessed": ".types",
    "WebhookEvent_EditRunProcessedParams": ".requests",
    "WebhookEvent_ExtractRunFailed": ".types",
    "WebhookEvent_ExtractRunFailedParams": ".requests",
    "WebhookEvent_ExtractRunProcessed": ".types",
    "WebhookEvent_ExtractRunProcessedParams": ".requests",
    "WebhookEvent_ExtractorCreated": ".types",
    "WebhookEvent_ExtractorCreatedParams": ".requests",
    "WebhookEvent_ExtractorDeleted": ".types",
    "WebhookEvent_ExtractorDeletedParams": ".requests",
    "WebhookEvent_ExtractorDraftUpdated": ".types",
    "WebhookEvent_ExtractorDraftUpdatedParams": ".requests",
    "WebhookEvent_ExtractorUpdated": ".types",
    "WebhookEvent_ExtractorUpdatedParams": ".requests",
    "WebhookEvent_ExtractorVersionPublished": ".types",
    "WebhookEvent_ExtractorVersionPublishedParams": ".requests",
    "WebhookEvent_ParseRunFailed": ".types",
    "WebhookEvent_ParseRunFailedParams": ".requests",
    "WebhookEvent_ParseRunProcessed": ".types",
    "WebhookEvent_ParseRunProcessedParams": ".requests",
    "WebhookEvent_SplitRunFailed": ".types",
    "WebhookEvent_SplitRunFailedParams": ".requests",
    "WebhookEvent_SplitRunProcessed": ".types",
    "WebhookEvent_SplitRunProcessedParams": ".requests",
    "WebhookEvent_SplitterCreated": ".types",
    "WebhookEvent_SplitterCreatedParams": ".requests",
    "WebhookEvent_SplitterDeleted": ".types",
    "WebhookEvent_SplitterDeletedParams": ".requests",
    "WebhookEvent_SplitterDraftUpdated": ".types",
    "WebhookEvent_SplitterDraftUpdatedParams": ".requests",
    "WebhookEvent_SplitterUpdated": ".types",
    "WebhookEvent_SplitterUpdatedParams": ".requests",
    "WebhookEvent_SplitterVersionPublished": ".types",
    "WebhookEvent_SplitterVersionPublishedParams": ".requests",
    "WebhookEvent_WorkflowCreated": ".types",
    "WebhookEvent_WorkflowCreatedParams": ".requests",
    "WebhookEvent_WorkflowDeleted": ".types",
    "WebhookEvent_WorkflowDeletedParams": ".requests",
    "WebhookEvent_WorkflowDeployed": ".types",
    "WebhookEvent_WorkflowDeployedParams": ".requests",
    "WebhookEvent_WorkflowRunCancelled": ".types",
    "WebhookEvent_WorkflowRunCancelledParams": ".requests",
    "WebhookEvent_WorkflowRunCompleted": ".types",
    "WebhookEvent_WorkflowRunCompletedParams": ".requests",
    "WebhookEvent_WorkflowRunFailed": ".types",
    "WebhookEvent_WorkflowRunFailedParams": ".requests",
    "WebhookEvent_WorkflowRunNeedsReview": ".types",
    "WebhookEvent_WorkflowRunNeedsReviewParams": ".requests",
    "WebhookEvent_WorkflowRunRejected": ".types",
    "WebhookEvent_WorkflowRunRejectedParams": ".requests",
    "WebhookEvent_WorkflowRunStepRunProcessed": ".types",
    "WebhookEvent_WorkflowRunStepRunProcessedParams": ".requests",
    "Workflow": ".types",
    "WorkflowCreatedWebhookEvent": ".types",
    "WorkflowCreatedWebhookEventParams": ".requests",
    "WorkflowDeletedWebhookEvent": ".types",
    "WorkflowDeletedWebhookEventParams": ".requests",
    "WorkflowDeployedWebhookEvent": ".types",
    "WorkflowDeployedWebhookEventParams": ".requests",
    "WorkflowParams": ".requests",
    "WorkflowReference": ".types",
    "WorkflowReferenceParams": ".requests",
    "WorkflowRun": ".types",
    "WorkflowRunCancelledWebhookEvent": ".types",
    "WorkflowRunCancelledWebhookEventParams": ".requests",
    "WorkflowRunCompletedWebhookEvent": ".types",
    "WorkflowRunCompletedWebhookEventParams": ".requests",
    "WorkflowRunFailedWebhookEvent": ".types",
    "WorkflowRunFailedWebhookEventParams": ".requests",
    "WorkflowRunNeedsReviewWebhookEvent": ".types",
    "WorkflowRunNeedsReviewWebhookEventParams": ".requests",
    "WorkflowRunParams": ".requests",
    "WorkflowRunRejectedWebhookEvent": ".types",
    "WorkflowRunRejectedWebhookEventParams": ".requests",
    "WorkflowRunStatus": ".types",
    "WorkflowRunStepRunProcessedWebhookEvent": ".types",
    "WorkflowRunStepRunProcessedWebhookEventParams": ".requests",
    "WorkflowRunSummary": ".types",
    "WorkflowRunSummaryParams": ".requests",
    "WorkflowRunsCreateBatchRequestInputsItem": ".workflow_runs",
    "WorkflowRunsCreateBatchRequestInputsItemFile": ".workflow_runs",
    "WorkflowRunsCreateBatchRequestInputsItemFileParams": ".workflow_runs",
    "WorkflowRunsCreateBatchRequestInputsItemParams": ".workflow_runs",
    "WorkflowRunsCreateBatchResponse": ".workflow_runs",
    "WorkflowRunsCreateBatchResponseParams": ".workflow_runs",
    "WorkflowRunsCreateRequestFile": ".workflow_runs",
    "WorkflowRunsCreateRequestFileParams": ".workflow_runs",
    "WorkflowRunsCreateRequestOutputsItem": ".workflow_runs",
    "WorkflowRunsCreateRequestOutputsItemParams": ".workflow_runs",
    "WorkflowRunsDeleteResponse": ".workflow_runs",
    "WorkflowRunsDeleteResponseParams": ".workflow_runs",
    "WorkflowRunsListResponse": ".workflow_runs",
    "WorkflowRunsListResponseParams": ".workflow_runs",
    "WorkflowStepBase": ".types",
    "WorkflowStepBaseParams": ".requests",
    "WorkflowSummary": ".types",
    "WorkflowSummaryParams": ".requests",
    "WorkflowVersion": ".types",
    "WorkflowVersionParams": ".requests",
    "WorkflowVersionSummary": ".types",
    "WorkflowVersionSummaryParams": ".requests",
    "__version__": ".version",
    "batch_processor_run": ".batch_processor_run",
    "classifier_versions": ".classifier_versions",
    "classifiers": ".classifiers",
    "classify_runs": ".classify_runs",
    "edit_runs": ".edit_runs",
    "evaluation_set_items": ".evaluation_set_items",
    "evaluation_set_runs": ".evaluation_set_runs",
    "evaluation_sets": ".evaluation_sets",
    "extract_runs": ".extract_runs",
    "extractor_versions": ".extractor_versions",
    "extractors": ".extractors",
    "files": ".files",
    "parse_runs": ".parse_runs",
    "processor": ".processor",
    "processor_run": ".processor_run",
    "processor_version": ".processor_version",
    "split_runs": ".split_runs",
    "splitter_versions": ".splitter_versions",
    "splitters": ".splitters",
    "workflow_runs": ".workflow_runs",
    "workflows": ".workflows",
}


def __getattr__(attr_name: str) -> typing.Any:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(f"No {attr_name} found in _dynamic_imports for module name -> {__name__}")
    try:
        module = import_module(module_name, __package__)
        if module_name == f".{attr_name}":
            return module
        else:
            return getattr(module, attr_name)
    except ImportError as e:
        raise ImportError(f"Failed to import {attr_name} from {module_name}: {e}") from e
    except AttributeError as e:
        raise AttributeError(f"Failed to get {attr_name} from {module_name}: {e}") from e


def __dir__():
    lazy_attrs = list(_dynamic_imports.keys())
    return sorted(lazy_attrs)


__all__ = [
    "ApiError",
    "ApiErrorParams",
    "ApiVersionEnum",
    "ArrayStrategy",
    "ArrayStrategyParams",
    "ArrayStrategyType",
    "AsyncExtend",
    "BadRequestError",
    "BatchProcessorRun",
    "BatchProcessorRunGetResponse",
    "BatchProcessorRunGetResponseParams",
    "BatchProcessorRunMetrics",
    "BatchProcessorRunMetricsParams",
    "BatchProcessorRunOptions",
    "BatchProcessorRunOptionsParams",
    "BatchProcessorRunParams",
    "BatchProcessorRunSource",
    "BatchProcessorRunStatus",
    "BatchRun",
    "BatchRunEntity",
    "BatchRunEntityParams",
    "BatchRunEntityVersion",
    "BatchRunEntityVersionParams",
    "BatchRunEntityVersion_ClassifierVersion",
    "BatchRunEntityVersion_ClassifierVersionParams",
    "BatchRunEntityVersion_ExtractorVersion",
    "BatchRunEntityVersion_ExtractorVersionParams",
    "BatchRunEntityVersion_SplitterVersion",
    "BatchRunEntityVersion_SplitterVersionParams",
    "BatchRunEntity_Classifier",
    "BatchRunEntity_ClassifierParams",
    "BatchRunEntity_Extractor",
    "BatchRunEntity_ExtractorParams",
    "BatchRunEntity_Splitter",
    "BatchRunEntity_SplitterParams",
    "BatchRunMetrics",
    "BatchRunMetricsParams",
    "BatchRunParams",
    "BatchRunStatus",
    "Block",
    "BlockDetails",
    "BlockDetailsParams",
    "BlockMetadata",
    "BlockMetadataPage",
    "BlockMetadataPageParams",
    "BlockMetadataParams",
    "BlockParams",
    "BlockPolygonItem",
    "BlockPolygonItemParams",
    "BlockType",
    "BoundingBox",
    "BoundingBoxParams",
    "Chunk",
    "ChunkMetadata",
    "ChunkMetadataPageRange",
    "ChunkMetadataPageRangeParams",
    "ChunkMetadataParams",
    "ChunkParams",
    "ChunkType",
    "Citation",
    "CitationPage",
    "CitationPageParams",
    "CitationParams",
    "Classification",
    "ClassificationParams",
    "Classifications",
    "ClassificationsParams",
    "Classifier",
    "ClassifierCreatedWebhookEvent",
    "ClassifierCreatedWebhookEventParams",
    "ClassifierDeletedWebhookEvent",
    "ClassifierDeletedWebhookEventParams",
    "ClassifierDraftUpdatedWebhookEvent",
    "ClassifierDraftUpdatedWebhookEventParams",
    "ClassifierParams",
    "ClassifierSummary",
    "ClassifierSummaryParams",
    "ClassifierUpdatedWebhookEvent",
    "ClassifierUpdatedWebhookEventParams",
    "ClassifierVersion",
    "ClassifierVersionParams",
    "ClassifierVersionPublishedWebhookEvent",
    "ClassifierVersionPublishedWebhookEventParams",
    "ClassifierVersionSummary",
    "ClassifierVersionSummaryParams",
    "ClassifierVersionsListResponse",
    "ClassifierVersionsListResponseParams",
    "ClassifiersListResponse",
    "ClassifiersListResponseParams",
    "ClassifyAdvancedOptions",
    "ClassifyAdvancedOptionsContext",
    "ClassifyAdvancedOptionsParams",
    "ClassifyConfig",
    "ClassifyConfigBaseProcessor",
    "ClassifyConfigParams",
    "ClassifyOutput",
    "ClassifyOutputParams",
    "ClassifyRequestClassifier",
    "ClassifyRequestClassifierParams",
    "ClassifyRequestFile",
    "ClassifyRequestFileParams",
    "ClassifyResult",
    "ClassifyResultParams",
    "ClassifyRun",
    "ClassifyRunFailedWebhookEvent",
    "ClassifyRunFailedWebhookEventParams",
    "ClassifyRunParams",
    "ClassifyRunProcessedWebhookEvent",
    "ClassifyRunProcessedWebhookEventParams",
    "ClassifyRunSummary",
    "ClassifyRunSummaryParams",
    "ClassifyRunsCreateRequestClassifier",
    "ClassifyRunsCreateRequestClassifierParams",
    "ClassifyRunsCreateRequestFile",
    "ClassifyRunsCreateRequestFileParams",
    "ClassifyRunsDeleteResponse",
    "ClassifyRunsDeleteResponseParams",
    "ClassifyRunsListResponse",
    "ClassifyRunsListResponseParams",
    "ClassifyStepRun",
    "ClassifyStepRunParams",
    "ClassifyStepRunStep",
    "ClassifyStepRunStepParams",
    "ConditionalExtractResult",
    "ConditionalExtractResultParams",
    "ConditionalExtractStepRun",
    "ConditionalExtractStepRunParams",
    "ConditionalExtractStepRunStep",
    "ConditionalExtractStepRunStepParams",
    "CreatedAt",
    "EditBoundingBox",
    "EditBoundingBoxParams",
    "EditConfig",
    "EditConfigAdvancedOptions",
    "EditConfigAdvancedOptionsParams",
    "EditConfigParams",
    "EditJson",
    "EditJsonExtendEditFieldType",
    "EditJsonParams",
    "EditObjectJson",
    "EditObjectJsonParams",
    "EditRequestFile",
    "EditRequestFileParams",
    "EditRootJson",
    "EditRootJsonParams",
    "EditRun",
    "EditRunFailedWebhookEvent",
    "EditRunFailedWebhookEventParams",
    "EditRunMetrics",
    "EditRunMetricsParams",
    "EditRunOutput",
    "EditRunOutputEditedFile",
    "EditRunOutputEditedFileParams",
    "EditRunOutputParams",
    "EditRunParams",
    "EditRunProcessedWebhookEvent",
    "EditRunProcessedWebhookEventParams",
    "EditRunStatus",
    "EditRunsCreateRequestFile",
    "EditRunsCreateRequestFileParams",
    "EditRunsDeleteResponse",
    "EditRunsDeleteResponseParams",
    "EditTextOptions",
    "EditTextOptionsParams",
    "EmptyBlockDetails",
    "Enum",
    "EnumOption",
    "EnumOptionParams",
    "EnumParams",
    "EvaluationSet",
    "EvaluationSetEntity",
    "EvaluationSetEntityParams",
    "EvaluationSetEntity_Classifier",
    "EvaluationSetEntity_ClassifierParams",
    "EvaluationSetEntity_Extractor",
    "EvaluationSetEntity_ExtractorParams",
    "EvaluationSetEntity_Splitter",
    "EvaluationSetEntity_SplitterParams",
    "EvaluationSetItem",
    "EvaluationSetItemParams",
    "EvaluationSetItemSummary",
    "EvaluationSetItemSummaryParams",
    "EvaluationSetItemsCreateRequestItemsItem",
    "EvaluationSetItemsCreateRequestItemsItemParams",
    "EvaluationSetItemsCreateResponse",
    "EvaluationSetItemsCreateResponseParams",
    "EvaluationSetItemsDeleteResponse",
    "EvaluationSetItemsDeleteResponseParams",
    "EvaluationSetItemsListResponse",
    "EvaluationSetItemsListResponseParams",
    "EvaluationSetParams",
    "EvaluationSetRun",
    "EvaluationSetRunEntity",
    "EvaluationSetRunEntityParams",
    "EvaluationSetRunEntityVersion",
    "EvaluationSetRunEntityVersionParams",
    "EvaluationSetRunEntityVersion_ClassifierVersion",
    "EvaluationSetRunEntityVersion_ClassifierVersionParams",
    "EvaluationSetRunEntityVersion_ExtractorVersion",
    "EvaluationSetRunEntityVersion_ExtractorVersionParams",
    "EvaluationSetRunEntityVersion_SplitterVersion",
    "EvaluationSetRunEntityVersion_SplitterVersionParams",
    "EvaluationSetRunEntity_Classifier",
    "EvaluationSetRunEntity_ClassifierParams",
    "EvaluationSetRunEntity_Extractor",
    "EvaluationSetRunEntity_ExtractorParams",
    "EvaluationSetRunEntity_Splitter",
    "EvaluationSetRunEntity_SplitterParams",
    "EvaluationSetRunMetrics",
    "EvaluationSetRunMetricsParams",
    "EvaluationSetRunOptions",
    "EvaluationSetRunOptionsParams",
    "EvaluationSetRunParams",
    "EvaluationSetsListResponse",
    "EvaluationSetsListResponseParams",
    "ExcelSheetRange",
    "ExcelSheetRangeParams",
    "Extend",
    "ExtendEnvironment",
    "Webhooks",
    "PollingOptions",
    "PollingTimeoutError",
    "ExternalDataValidationResult",
    "ExternalDataValidationResultParams",
    "ExternalDataValidationResultResponse",
    "ExternalDataValidationResultResponseParams",
    "ExternalDataValidationStepRun",
    "ExternalDataValidationStepRunParams",
    "ExternalDataValidationStepRunStep",
    "ExternalDataValidationStepRunStepParams",
    "ExtractAdvancedOptions",
    "ExtractAdvancedOptionsArrayCitationStrategy",
    "ExtractAdvancedOptionsExcelSheetSelectionStrategy",
    "ExtractAdvancedOptionsParams",
    "ExtractAdvancedOptionsReviewAgent",
    "ExtractAdvancedOptionsReviewAgentParams",
    "ExtractChunkingOptions",
    "ExtractChunkingOptionsChunkSelectionStrategy",
    "ExtractChunkingOptionsChunkingStrategy",
    "ExtractChunkingOptionsParams",
    "ExtractConfig",
    "ExtractConfigJson",
    "ExtractConfigJsonBaseProcessor",
    "ExtractConfigJsonParams",
    "ExtractConfigLegacy",
    "ExtractConfigLegacyBaseProcessor",
    "ExtractConfigLegacyParams",
    "ExtractConfigParams",
    "ExtractOutput",
    "ExtractOutputEdits",
    "ExtractOutputEditsParams",
    "ExtractOutputJson",
    "ExtractOutputJsonParams",
    "ExtractOutputLegacy",
    "ExtractOutputLegacyParams",
    "ExtractOutputMetadata",
    "ExtractOutputMetadataParams",
    "ExtractOutputMetadataValue",
    "ExtractOutputMetadataValueParams",
    "ExtractOutputParams",
    "ExtractRequestExtractor",
    "ExtractRequestExtractorParams",
    "ExtractRequestFile",
    "ExtractRequestFileParams",
    "ExtractResult",
    "ExtractResultParams",
    "ExtractRun",
    "ExtractRunFailedWebhookEvent",
    "ExtractRunFailedWebhookEventParams",
    "ExtractRunParams",
    "ExtractRunProcessedWebhookEvent",
    "ExtractRunProcessedWebhookEventParams",
    "ExtractRunSummary",
    "ExtractRunSummaryParams",
    "ExtractRunsCreateRequestExtractor",
    "ExtractRunsCreateRequestExtractorParams",
    "ExtractRunsCreateRequestFile",
    "ExtractRunsCreateRequestFileParams",
    "ExtractRunsDeleteResponse",
    "ExtractRunsDeleteResponseParams",
    "ExtractRunsListResponse",
    "ExtractRunsListResponseParams",
    "ExtractStepRun",
    "ExtractStepRunParams",
    "ExtractStepRunStep",
    "ExtractStepRunStepParams",
    "ExtractionField",
    "ExtractionFieldParams",
    "ExtractionFieldResult",
    "ExtractionFieldResultParams",
    "ExtractionFieldResultReference",
    "ExtractionFieldResultReferenceBoundingBoxesItem",
    "ExtractionFieldResultReferenceBoundingBoxesItemParams",
    "ExtractionFieldResultReferenceParams",
    "ExtractionFieldResultType",
    "ExtractionFieldType",
    "Extractor",
    "ExtractorCreatedWebhookEvent",
    "ExtractorCreatedWebhookEventParams",
    "ExtractorDeletedWebhookEvent",
    "ExtractorDeletedWebhookEventParams",
    "ExtractorDraftUpdatedWebhookEvent",
    "ExtractorDraftUpdatedWebhookEventParams",
    "ExtractorParams",
    "ExtractorSummary",
    "ExtractorSummaryParams",
    "ExtractorUpdatedWebhookEvent",
    "ExtractorUpdatedWebhookEventParams",
    "ExtractorVersion",
    "ExtractorVersionParams",
    "ExtractorVersionPublishedWebhookEvent",
    "ExtractorVersionPublishedWebhookEventParams",
    "ExtractorVersionSummary",
    "ExtractorVersionSummaryParams",
    "ExtractorVersionsListResponse",
    "ExtractorVersionsListResponseParams",
    "ExtractorsListResponse",
    "ExtractorsListResponseParams",
    "FigureDetails",
    "FigureDetailsFigureType",
    "FigureDetailsParams",
    "File",
    "FileContents",
    "FileContentsPagesItem",
    "FileContentsPagesItemParams",
    "FileContentsParams",
    "FileContentsSectionsItem",
    "FileContentsSectionsItemParams",
    "FileContentsSheetsItem",
    "FileContentsSheetsItemParams",
    "FileFromId",
    "FileFromIdParams",
    "FileFromText",
    "FileFromTextParams",
    "FileFromUrl",
    "FileFromUrlParams",
    "FileMetadata",
    "FileMetadataParams",
    "FileParams",
    "FileSummary",
    "FileSummaryParams",
    "FileType",
    "FilesDeleteResponse",
    "FilesDeleteResponseParams",
    "FilesListResponse",
    "FilesListResponseParams",
    "ForbiddenError",
    "Insight",
    "InsightParams",
    "InternalServerError",
    "JsonObject",
    "LegacyBatchProcessorRun",
    "LegacyBatchProcessorRunMetrics",
    "LegacyBatchProcessorRunMetricsParams",
    "LegacyBatchProcessorRunOptions",
    "LegacyBatchProcessorRunOptionsParams",
    "LegacyBatchProcessorRunParams",
    "LegacyBatchProcessorRunSource",
    "LegacyBatchProcessorRunStatus",
    "LegacyClassification",
    "LegacyClassificationAdvancedOptions",
    "LegacyClassificationAdvancedOptionsContext",
    "LegacyClassificationAdvancedOptionsParams",
    "LegacyClassificationConfig",
    "LegacyClassificationConfigBaseProcessor",
    "LegacyClassificationConfigParams",
    "LegacyClassificationParams",
    "LegacyClassifierOutput",
    "LegacyClassifierOutputParams",
    "LegacyDocumentProcessorRunCredits",
    "LegacyDocumentProcessorRunCreditsParams",
    "LegacyError",
    "LegacyErrorParams",
    "LegacyExtendError",
    "LegacyExtendErrorParams",
    "LegacyExtractChunkingOptions",
    "LegacyExtractChunkingOptionsChunkSelectionStrategy",
    "LegacyExtractChunkingOptionsChunkingStrategy",
    "LegacyExtractChunkingOptionsParams",
    "LegacyExtractionAdvancedOptions",
    "LegacyExtractionAdvancedOptionsArrayCitationStrategy",
    "LegacyExtractionAdvancedOptionsExcelSheetSelectionStrategy",
    "LegacyExtractionAdvancedOptionsParams",
    "LegacyExtractionAdvancedOptionsReviewAgent",
    "LegacyExtractionAdvancedOptionsReviewAgentParams",
    "LegacyExtractionConfig",
    "LegacyExtractionConfigBaseProcessor",
    "LegacyExtractionConfigParams",
    "LegacyExtractionField",
    "LegacyExtractionFieldParams",
    "LegacyExtractionFieldResult",
    "LegacyExtractionFieldResultParams",
    "LegacyExtractionFieldResultType",
    "LegacyExtractionFieldType",
    "LegacyExtractionOutput",
    "LegacyExtractionOutputEdits",
    "LegacyExtractionOutputEditsParams",
    "LegacyExtractionOutputParams",
    "LegacyFieldsArrayOutput",
    "LegacyFieldsArrayOutputParams",
    "LegacyJsonObject",
    "LegacyJsonOutput",
    "LegacyJsonOutputMetadataValue",
    "LegacyJsonOutputMetadataValueCitationsItem",
    "LegacyJsonOutputMetadataValueCitationsItemParams",
    "LegacyJsonOutputMetadataValueCitationsItemPolygonItem",
    "LegacyJsonOutputMetadataValueCitationsItemPolygonItemParams",
    "LegacyJsonOutputMetadataValueParams",
    "LegacyJsonOutputParams",
    "LegacyListProcessorsProcessor",
    "LegacyListProcessorsProcessorParams",
    "LegacyListProcessorsProcessorVersion",
    "LegacyListProcessorsProcessorVersionParams",
    "LegacyListProcessorsResponse",
    "LegacyListProcessorsResponseParams",
    "LegacyMaxPageSize",
    "LegacyNextPageToken",
    "LegacyProcessor",
    "LegacyProcessorId",
    "LegacyProcessorOutput",
    "LegacyProcessorOutputParams",
    "LegacyProcessorParams",
    "LegacyProcessorRun",
    "LegacyProcessorRunConfig",
    "LegacyProcessorRunConfigParams",
    "LegacyProcessorRunConfig_Classify",
    "LegacyProcessorRunConfig_ClassifyParams",
    "LegacyProcessorRunConfig_Extract",
    "LegacyProcessorRunConfig_ExtractParams",
    "LegacyProcessorRunConfig_Splitter",
    "LegacyProcessorRunConfig_SplitterParams",
    "LegacyProcessorRunFileInput",
    "LegacyProcessorRunFileInputParams",
    "LegacyProcessorRunMergedProcessorsItem",
    "LegacyProcessorRunMergedProcessorsItemParams",
    "LegacyProcessorRunParams",
    "LegacyProcessorRunSummary",
    "LegacyProcessorRunSummaryParams",
    "LegacyProcessorRunSummaryType",
    "LegacyProcessorRunType",
    "LegacyProcessorStatus",
    "LegacyProcessorType",
    "LegacyProcessorVersion",
    "LegacyProcessorVersionConfig",
    "LegacyProcessorVersionConfigParams",
    "LegacyProcessorVersionConfig_Classify",
    "LegacyProcessorVersionConfig_ClassifyParams",
    "LegacyProcessorVersionConfig_Extract",
    "LegacyProcessorVersionConfig_ExtractParams",
    "LegacyProcessorVersionConfig_Splitter",
    "LegacyProcessorVersionConfig_SplitterParams",
    "LegacyProcessorVersionParams",
    "LegacyProvidedClassifierOutput",
    "LegacyProvidedClassifierOutputParams",
    "LegacyProvidedExtractionFieldResult",
    "LegacyProvidedExtractionFieldResultParams",
    "LegacyProvidedExtractionFieldResultType",
    "LegacyProvidedExtractionOutput",
    "LegacyProvidedExtractionOutputParams",
    "LegacyProvidedFieldsArrayOutput",
    "LegacyProvidedFieldsArrayOutputParams",
    "LegacyProvidedJsonOutput",
    "LegacyProvidedJsonOutputParams",
    "LegacyProvidedProcessorOutput",
    "LegacyProvidedProcessorOutputParams",
    "LegacyProvidedSplitterOutput",
    "LegacyProvidedSplitterOutputParams",
    "LegacyProvidedSplitterOutputSplitsItem",
    "LegacyProvidedSplitterOutputSplitsItemParams",
    "LegacySortByEnum",
    "LegacySortDirEnum",
    "LegacySplitterAdvancedOptions",
    "LegacySplitterAdvancedOptionsParams",
    "LegacySplitterAdvancedOptionsSplitMethod",
    "LegacySplitterConfig",
    "LegacySplitterConfigBaseProcessor",
    "LegacySplitterConfigParams",
    "LegacySplitterOutput",
    "LegacySplitterOutputParams",
    "LegacySplitterOutputSplitsItem",
    "LegacySplitterOutputSplitsItemParams",
    "MaxPageSize",
    "MergeExtractResult",
    "MergeExtractResultMergedExtractorsItem",
    "MergeExtractResultMergedExtractorsItemParams",
    "MergeExtractResultParams",
    "MergeExtractStepRun",
    "MergeExtractStepRunParams",
    "MergeExtractStepRunStep",
    "MergeExtractStepRunStepParams",
    "NextPageToken",
    "NotFoundError",
    "PageRanges",
    "PageRangesItem",
    "PageRangesItemParams",
    "PageRangesParams",
    "ParentSplit",
    "ParentSplitParams",
    "ParseConfig",
    "ParseConfigAdvancedOptions",
    "ParseConfigAdvancedOptionsParams",
    "ParseConfigAdvancedOptionsReturnOcr",
    "ParseConfigAdvancedOptionsReturnOcrParams",
    "ParseConfigBlockOptions",
    "ParseConfigBlockOptionsFigures",
    "ParseConfigBlockOptionsFiguresParams",
    "ParseConfigBlockOptionsParams",
    "ParseConfigBlockOptionsTables",
    "ParseConfigBlockOptionsTablesAgentic",
    "ParseConfigBlockOptionsTablesAgenticParams",
    "ParseConfigBlockOptionsTablesParams",
    "ParseConfigBlockOptionsTablesTargetFormat",
    "ParseConfigBlockOptionsText",
    "ParseConfigBlockOptionsTextAgentic",
    "ParseConfigBlockOptionsTextAgenticParams",
    "ParseConfigBlockOptionsTextParams",
    "ParseConfigChunkingStrategy",
    "ParseConfigChunkingStrategyOptions",
    "ParseConfigChunkingStrategyOptionsParams",
    "ParseConfigChunkingStrategyParams",
    "ParseConfigChunkingStrategyType",
    "ParseConfigEngine",
    "ParseConfigParams",
    "ParseConfigTarget",
    "ParseRequestFile",
    "ParseRequestFileParams",
    "ParseRequestResponseType",
    "ParseResult",
    "ParseResultParams",
    "ParseRun",
    "ParseRunFailedWebhookEvent",
    "ParseRunFailedWebhookEventParams",
    "ParseRunMetrics",
    "ParseRunMetricsParams",
    "ParseRunOutput",
    "ParseRunOutputOcr",
    "ParseRunOutputOcrParams",
    "ParseRunOutputOcrWordsItem",
    "ParseRunOutputOcrWordsItemParams",
    "ParseRunOutputParams",
    "ParseRunParams",
    "ParseRunProcessedWebhookEvent",
    "ParseRunProcessedWebhookEventParams",
    "ParseRunStatus",
    "ParseRunStatusEnum",
    "ParseRunStatusParams",
    "ParseRunStatusStatus",
    "ParseRunsCreateRequestFile",
    "ParseRunsCreateRequestFileParams",
    "ParseRunsDeleteResponse",
    "ParseRunsDeleteResponseParams",
    "ParseRunsRetrieveRequestResponseType",
    "ParseStepRun",
    "ParseStepRunParams",
    "ParseStepRunStep",
    "ParseStepRunStepParams",
    "PaymentRequiredError",
    "Polygon",
    "PolygonParams",
    "ProcessorCreateRequestConfig",
    "ProcessorCreateRequestConfigParams",
    "ProcessorCreateRequestConfig_Classify",
    "ProcessorCreateRequestConfig_ClassifyParams",
    "ProcessorCreateRequestConfig_Extract",
    "ProcessorCreateRequestConfig_ExtractParams",
    "ProcessorCreateRequestConfig_Splitter",
    "ProcessorCreateRequestConfig_SplitterParams",
    "ProcessorCreateResponse",
    "ProcessorCreateResponseParams",
    "ProcessorListRequestSortBy",
    "ProcessorListRequestSortDir",
    "ProcessorRunCancelResponse",
    "ProcessorRunCancelResponseParams",
    "ProcessorRunCreateRequestConfig",
    "ProcessorRunCreateRequestConfigParams",
    "ProcessorRunCreateRequestConfig_Classify",
    "ProcessorRunCreateRequestConfig_ClassifyParams",
    "ProcessorRunCreateRequestConfig_Extract",
    "ProcessorRunCreateRequestConfig_ExtractParams",
    "ProcessorRunCreateRequestConfig_Splitter",
    "ProcessorRunCreateRequestConfig_SplitterParams",
    "ProcessorRunCreateResponse",
    "ProcessorRunCreateResponseParams",
    "ProcessorRunDeleteResponse",
    "ProcessorRunDeleteResponseParams",
    "ProcessorRunGetResponse",
    "ProcessorRunGetResponseParams",
    "ProcessorRunListRequestSource",
    "ProcessorRunListResponse",
    "ProcessorRunListResponseParams",
    "ProcessorRunStatus",
    "ProcessorUpdateRequestConfig",
    "ProcessorUpdateRequestConfigParams",
    "ProcessorUpdateRequestConfig_Classify",
    "ProcessorUpdateRequestConfig_ClassifyParams",
    "ProcessorUpdateRequestConfig_Extract",
    "ProcessorUpdateRequestConfig_ExtractParams",
    "ProcessorUpdateRequestConfig_Splitter",
    "ProcessorUpdateRequestConfig_SplitterParams",
    "ProcessorUpdateResponse",
    "ProcessorUpdateResponseParams",
    "ProcessorVersionCreateRequestConfig",
    "ProcessorVersionCreateRequestConfigParams",
    "ProcessorVersionCreateRequestConfig_Classify",
    "ProcessorVersionCreateRequestConfig_ClassifyParams",
    "ProcessorVersionCreateRequestConfig_Extract",
    "ProcessorVersionCreateRequestConfig_ExtractParams",
    "ProcessorVersionCreateRequestConfig_Splitter",
    "ProcessorVersionCreateRequestConfig_SplitterParams",
    "ProcessorVersionCreateRequestReleaseType",
    "ProcessorVersionCreateResponse",
    "ProcessorVersionCreateResponseParams",
    "ProcessorVersionGetResponse",
    "ProcessorVersionGetResponseParams",
    "ProcessorVersionListResponse",
    "ProcessorVersionListResponseParams",
    "ProcessorVersionString",
    "ProvidedClassifyOutput",
    "ProvidedClassifyOutputParams",
    "ProvidedExtractOutput",
    "ProvidedExtractOutputParams",
    "ProvidedProcessorOutput",
    "ProvidedProcessorOutputParams",
    "ProvidedSplitOutput",
    "ProvidedSplitOutputParams",
    "ProvidedSplitOutputSplitsItem",
    "ProvidedSplitOutputSplitsItemParams",
    "ReleaseType",
    "RuleValidationResult",
    "RuleValidationResultParams",
    "RuleValidationResultRulesItem",
    "RuleValidationResultRulesItemFailureReason",
    "RuleValidationResultRulesItemParams",
    "RuleValidationStepRun",
    "RuleValidationStepRunParams",
    "RuleValidationStepRunStep",
    "RuleValidationStepRunStepParams",
    "RunMetadata",
    "RunPriority",
    "RunSecrets",
    "RunSource",
    "RunSourceId",
    "RunUsage",
    "RunUsageParams",
    "SortBy",
    "SortDir",
    "SplitAdvancedOptions",
    "SplitAdvancedOptionsParams",
    "SplitAdvancedOptionsSplitMethod",
    "SplitConfig",
    "SplitConfigBaseProcessor",
    "SplitConfigParams",
    "SplitOutput",
    "SplitOutputParams",
    "SplitOutputSplitsItem",
    "SplitOutputSplitsItemParams",
    "SplitRequestFile",
    "SplitRequestFileParams",
    "SplitRequestSplitter",
    "SplitRequestSplitterParams",
    "SplitResult",
    "SplitResultParams",
    "SplitRun",
    "SplitRunFailedWebhookEvent",
    "SplitRunFailedWebhookEventParams",
    "SplitRunParams",
    "SplitRunProcessedWebhookEvent",
    "SplitRunProcessedWebhookEventParams",
    "SplitRunSummary",
    "SplitRunSummaryParams",
    "SplitRunsCreateRequestFile",
    "SplitRunsCreateRequestFileParams",
    "SplitRunsCreateRequestSplitter",
    "SplitRunsCreateRequestSplitterParams",
    "SplitRunsDeleteResponse",
    "SplitRunsDeleteResponseParams",
    "SplitRunsListResponse",
    "SplitRunsListResponseParams",
    "SplitStepRun",
    "SplitStepRunParams",
    "SplitStepRunStep",
    "SplitStepRunStepParams",
    "Splitter",
    "SplitterCreatedWebhookEvent",
    "SplitterCreatedWebhookEventParams",
    "SplitterDeletedWebhookEvent",
    "SplitterDeletedWebhookEventParams",
    "SplitterDraftUpdatedWebhookEvent",
    "SplitterDraftUpdatedWebhookEventParams",
    "SplitterParams",
    "SplitterSummary",
    "SplitterSummaryParams",
    "SplitterUpdatedWebhookEvent",
    "SplitterUpdatedWebhookEventParams",
    "SplitterVersion",
    "SplitterVersionParams",
    "SplitterVersionPublishedWebhookEvent",
    "SplitterVersionPublishedWebhookEventParams",
    "SplitterVersionSummary",
    "SplitterVersionSummaryParams",
    "SplitterVersionsListResponse",
    "SplitterVersionsListResponseParams",
    "SplittersListResponse",
    "SplittersListResponseParams",
    "StepRun",
    "StepRunBase",
    "StepRunBaseParams",
    "StepRunBaseStatus",
    "StepRunParams",
    "TableCellDetails",
    "TableCellDetailsParams",
    "TableDetails",
    "TableDetailsParams",
    "TooManyRequestsError",
    "TooManyRequestsErrorBody",
    "TooManyRequestsErrorBodyParams",
    "UnauthorizedError",
    "UnprocessableEntityError",
    "UpdatedAt",
    "VersionDescription",
    "WebhookEvent",
    "WebhookEventParams",
    "WebhookEvent_ClassifierCreated",
    "WebhookEvent_ClassifierCreatedParams",
    "WebhookEvent_ClassifierDeleted",
    "WebhookEvent_ClassifierDeletedParams",
    "WebhookEvent_ClassifierDraftUpdated",
    "WebhookEvent_ClassifierDraftUpdatedParams",
    "WebhookEvent_ClassifierUpdated",
    "WebhookEvent_ClassifierUpdatedParams",
    "WebhookEvent_ClassifierVersionPublished",
    "WebhookEvent_ClassifierVersionPublishedParams",
    "WebhookEvent_ClassifyRunFailed",
    "WebhookEvent_ClassifyRunFailedParams",
    "WebhookEvent_ClassifyRunProcessed",
    "WebhookEvent_ClassifyRunProcessedParams",
    "WebhookEvent_EditRunFailed",
    "WebhookEvent_EditRunFailedParams",
    "WebhookEvent_EditRunProcessed",
    "WebhookEvent_EditRunProcessedParams",
    "WebhookEvent_ExtractRunFailed",
    "WebhookEvent_ExtractRunFailedParams",
    "WebhookEvent_ExtractRunProcessed",
    "WebhookEvent_ExtractRunProcessedParams",
    "WebhookEvent_ExtractorCreated",
    "WebhookEvent_ExtractorCreatedParams",
    "WebhookEvent_ExtractorDeleted",
    "WebhookEvent_ExtractorDeletedParams",
    "WebhookEvent_ExtractorDraftUpdated",
    "WebhookEvent_ExtractorDraftUpdatedParams",
    "WebhookEvent_ExtractorUpdated",
    "WebhookEvent_ExtractorUpdatedParams",
    "WebhookEvent_ExtractorVersionPublished",
    "WebhookEvent_ExtractorVersionPublishedParams",
    "WebhookEvent_ParseRunFailed",
    "WebhookEvent_ParseRunFailedParams",
    "WebhookEvent_ParseRunProcessed",
    "WebhookEvent_ParseRunProcessedParams",
    "WebhookEvent_SplitRunFailed",
    "WebhookEvent_SplitRunFailedParams",
    "WebhookEvent_SplitRunProcessed",
    "WebhookEvent_SplitRunProcessedParams",
    "WebhookEvent_SplitterCreated",
    "WebhookEvent_SplitterCreatedParams",
    "WebhookEvent_SplitterDeleted",
    "WebhookEvent_SplitterDeletedParams",
    "WebhookEvent_SplitterDraftUpdated",
    "WebhookEvent_SplitterDraftUpdatedParams",
    "WebhookEvent_SplitterUpdated",
    "WebhookEvent_SplitterUpdatedParams",
    "WebhookEvent_SplitterVersionPublished",
    "WebhookEvent_SplitterVersionPublishedParams",
    "WebhookEvent_WorkflowCreated",
    "WebhookEvent_WorkflowCreatedParams",
    "WebhookEvent_WorkflowDeleted",
    "WebhookEvent_WorkflowDeletedParams",
    "WebhookEvent_WorkflowDeployed",
    "WebhookEvent_WorkflowDeployedParams",
    "WebhookEvent_WorkflowRunCancelled",
    "WebhookEvent_WorkflowRunCancelledParams",
    "WebhookEvent_WorkflowRunCompleted",
    "WebhookEvent_WorkflowRunCompletedParams",
    "WebhookEvent_WorkflowRunFailed",
    "WebhookEvent_WorkflowRunFailedParams",
    "WebhookEvent_WorkflowRunNeedsReview",
    "WebhookEvent_WorkflowRunNeedsReviewParams",
    "WebhookEvent_WorkflowRunRejected",
    "WebhookEvent_WorkflowRunRejectedParams",
    "WebhookEvent_WorkflowRunStepRunProcessed",
    "WebhookEvent_WorkflowRunStepRunProcessedParams",
    "Workflow",
    "WorkflowCreatedWebhookEvent",
    "WorkflowCreatedWebhookEventParams",
    "WorkflowDeletedWebhookEvent",
    "WorkflowDeletedWebhookEventParams",
    "WorkflowDeployedWebhookEvent",
    "WorkflowDeployedWebhookEventParams",
    "WorkflowParams",
    "WorkflowReference",
    "WorkflowReferenceParams",
    "WorkflowRun",
    "WorkflowRunCancelledWebhookEvent",
    "WorkflowRunCancelledWebhookEventParams",
    "WorkflowRunCompletedWebhookEvent",
    "WorkflowRunCompletedWebhookEventParams",
    "WorkflowRunFailedWebhookEvent",
    "WorkflowRunFailedWebhookEventParams",
    "WorkflowRunNeedsReviewWebhookEvent",
    "WorkflowRunNeedsReviewWebhookEventParams",
    "WorkflowRunParams",
    "WorkflowRunRejectedWebhookEvent",
    "WorkflowRunRejectedWebhookEventParams",
    "WorkflowRunStatus",
    "WorkflowRunStepRunProcessedWebhookEvent",
    "WorkflowRunStepRunProcessedWebhookEventParams",
    "WorkflowRunSummary",
    "WorkflowRunSummaryParams",
    "WorkflowRunsCreateBatchRequestInputsItem",
    "WorkflowRunsCreateBatchRequestInputsItemFile",
    "WorkflowRunsCreateBatchRequestInputsItemFileParams",
    "WorkflowRunsCreateBatchRequestInputsItemParams",
    "WorkflowRunsCreateBatchResponse",
    "WorkflowRunsCreateBatchResponseParams",
    "WorkflowRunsCreateRequestFile",
    "WorkflowRunsCreateRequestFileParams",
    "WorkflowRunsCreateRequestOutputsItem",
    "WorkflowRunsCreateRequestOutputsItemParams",
    "WorkflowRunsDeleteResponse",
    "WorkflowRunsDeleteResponseParams",
    "WorkflowRunsListResponse",
    "WorkflowRunsListResponseParams",
    "WorkflowStepBase",
    "WorkflowStepBaseParams",
    "WorkflowSummary",
    "WorkflowSummaryParams",
    "WorkflowVersion",
    "WorkflowVersionParams",
    "WorkflowVersionSummary",
    "WorkflowVersionSummaryParams",
    "__version__",
    "batch_processor_run",
    "classifier_versions",
    "classifiers",
    "classify_runs",
    "edit_runs",
    "evaluation_set_items",
    "evaluation_set_runs",
    "evaluation_sets",
    "extract_runs",
    "extractor_versions",
    "extractors",
    "files",
    "parse_runs",
    "processor",
    "processor_run",
    "processor_version",
    "split_runs",
    "splitter_versions",
    "splitters",
    "workflow_runs",
    "workflows",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.step_run_base_status import StepRunBaseStatus
from .file_summary import FileSummaryParams


class StepRunBaseParams(typing_extensions.TypedDict):
    """
    Base properties shared by all step run types.
    """

    object: typing.Literal["workflow_step_run"]
    """
    The type of object. In this case, it will always be `"workflow_step_run"`.
    """

    id: str
    """
    The ID of the workflow step run.
    
    Example: `"workflow_step_run_xKm9pNv3qWsY_jL2tR5Dh"`
    """

    workflow_run_id: typing_extensions.Annotated[str, FieldMetadata(alias="workflowRunId")]
    """
    The ID of the parent workflow run.
    
    Example: `"workflow_run_xKm9pNv3qWsY_jL2tR5Dh"`
    """

    status: StepRunBaseStatus
    """
    The status of the workflow step run:
    * `"PENDING"` - The step run is waiting to be executed
    * `"WAITING"` - The step run is waiting for a dependency to complete
    * `"PROCESSING"` - The step run is currently executing
    * `"PROCESSED"` - The step run completed successfully
    * `"FAILED"` - The step run encountered an error
    * `"CANCELLED"` - The step run was cancelled
    """

    files: typing.Sequence[FileSummaryParams]
    """
    The files associated with this step run.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from .legacy_classifier_output import LegacyClassifierOutputParams
from .legacy_extraction_output import LegacyExtractionOutputParams
from .legacy_splitter_output import LegacySplitterOutputParams

LegacyProcessorOutputParams = typing.Union[
    LegacyExtractionOutputParams, LegacyClassifierOutputParams, LegacySplitterOutputParams
]



# This file was auto-generated by Fern from our API Definition.

import typing

from .conditional_extract_result import ConditionalExtractResultParams
from .conditional_extract_step_run_step import ConditionalExtractStepRunStepParams
from .step_run_base import StepRunBaseParams


class ConditionalExtractStepRunParams(StepRunBaseParams):
    step: ConditionalExtractStepRunStepParams
    result: typing.Optional[ConditionalExtractResultParams]
    """
    The result of this conditional extract step. Currently, `result` is always present for returned step runs. It is nullable to allow for future support of returning step runs with non-successful statuses.
    """



# This file was auto-generated by Fern from our API Definition.

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.webhook_payload_format import WebhookPayloadFormat


class WebhookPayloadOptionsParams(typing_extensions.TypedDict):
    """
    Configuration for how webhook payloads are delivered.
    """

    format: WebhookPayloadFormat
    url_threshold_bytes: typing_extensions.NotRequired[
        typing_extensions.Annotated[int, FieldMetadata(alias="urlThresholdBytes")]
    ]
    """
    When `format` is `url`, payloads larger than this threshold (in bytes) are delivered as a signed download URL instead of inline JSON. Only applicable when `format` is `url`.
    """



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class EditRunStatus(enum.StrEnum):
    """
    The status of the edit run:
    * `"PROCESSING"` - The file is still being processed
    * `"PROCESSED"` - The file was successfully edited
    * `"FAILED"` - The editing failed (see `failureReason` for details)
    """

    PROCESSING = "PROCESSING"
    PROCESSED = "PROCESSED"
    FAILED = "FAILED"
    _UNKNOWN = "__EDITRUNSTATUS_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "EditRunStatus":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        processing: typing.Callable[[], T_Result],
        processed: typing.Callable[[], T_Result],
        failed: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is EditRunStatus.PROCESSING:
            return processing()
        if self is EditRunStatus.PROCESSED:
            return processed()
        if self is EditRunStatus.FAILED:
            return failed()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel
from .legacy_splitter_advanced_options_split_method import LegacySplitterAdvancedOptionsSplitMethod
from .page_ranges import PageRanges


class LegacySplitterAdvancedOptions(UncheckedBaseModel):
    split_identifier_rules: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="splitIdentifierRules")
    ] = pydantic.Field(alias="splitIdentifierRules", default=None)
    """
    Custom rules for identifying split points.
    """

    split_method: typing_extensions.Annotated[
        typing.Optional[LegacySplitterAdvancedOptionsSplitMethod], FieldMetadata(alias="splitMethod")
    ] = pydantic.Field(alias="splitMethod", default=None)
    """
    The method to use for splitting documents. `high_precision` is more accurate but slower, while `low_latency` is faster but less precise.
    
    **Deprecated:** For `splitting_light` >= 1.3.0 and `splitting_performance` >= 1.5.0, this field has no impact and is ignored if provided. It is still accepted for compatibility with older integrations.
    """

    split_excel_documents_by_sheet_enabled: typing_extensions.Annotated[
        typing.Optional[bool], FieldMetadata(alias="splitExcelDocumentsBySheetEnabled")
    ] = pydantic.Field(alias="splitExcelDocumentsBySheetEnabled", default=None)
    """
    For Excel documents, split by worksheet.
    """

    fixed_page_limit: typing_extensions.Annotated[typing.Optional[int], FieldMetadata(alias="fixedPageLimit")] = (
        pydantic.Field(alias="fixedPageLimit", default=None)
    )
    """
    Limit processing to a specific number of pages from the beginning of the document. See [Page Ranges](https://docs.extend.ai/2026-02-09/product/page-ranges).
    """

    page_ranges: typing_extensions.Annotated[typing.Optional[PageRanges], FieldMetadata(alias="pageRanges")] = (
        pydantic.Field(alias="pageRanges", default=None)
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

from .extract_output_json import ExtractOutputJson
from .extract_output_legacy import ExtractOutputLegacy

ExtractOutput = typing.Union[ExtractOutputJson, ExtractOutputLegacy]



# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel, UnionMetadata
from .json_object import JsonObject
from .legacy_classification import LegacyClassification
from .legacy_classification_advanced_options import LegacyClassificationAdvancedOptions
from .legacy_classification_config_base_processor import LegacyClassificationConfigBaseProcessor
from .legacy_extraction_advanced_options import LegacyExtractionAdvancedOptions
from .legacy_extraction_config_base_processor import LegacyExtractionConfigBaseProcessor
from .legacy_splitter_advanced_options import LegacySplitterAdvancedOptions
from .legacy_splitter_config_base_processor import LegacySplitterConfigBaseProcessor
from .parse_config import ParseConfig


class LegacyProcessorVersionConfig_Classify(UncheckedBaseModel):
    """
    The configuration settings for this version of the document processor. The structure of this object will vary depending on the processor type.

    See the configuration section in the "Guides" tab, for yout specific processor type, for more details on the configuration settings.
    """

    type: typing.Literal["CLASSIFY"] = "CLASSIFY"
    base_processor: typing_extensions.Annotated[
        typing.Optional[LegacyClassificationConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = pydantic.Field(alias="baseProcessor", default=None)
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = (
        pydantic.Field(alias="baseVersion", default=None)
    )
    classifications: typing.List[LegacyClassification]
    classification_rules: typing_extensions.Annotated[
        typing.Optional[str], FieldMetadata(alias="classificationRules")
    ] = pydantic.Field(alias="classificationRules", default=None)
    advanced_options: typing_extensions.Annotated[
        typing.Optional[LegacyClassificationAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = pydantic.Field(alias="advancedOptions", default=None)
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class LegacyProcessorVersionConfig_Extract(UncheckedBaseModel):
    """
    The configuration settings for this version of the document processor. The structure of this object will vary depending on the processor type.

    See the configuration section in the "Guides" tab, for yout specific processor type, for more details on the configuration settings.
    """

    type: typing.Literal["EXTRACT"] = "EXTRACT"
    base_processor: typing_extensions.Annotated[
        typing.Optional[LegacyExtractionConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = pydantic.Field(alias="baseProcessor", default=None)
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = (
        pydantic.Field(alias="baseVersion", default=None)
    )
    extraction_rules: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="extractionRules")] = (
        pydantic.Field(alias="extractionRules", default=None)
    )
    schema_: typing_extensions.Annotated[typing.Optional[JsonObject], FieldMetadata(alias="schema")] = pydantic.Field(
        alias="schema", default=None
    )
    fields: typing.Optional[typing.List["LegacyExtractionField"]] = None
    advanced_options: typing_extensions.Annotated[
        typing.Optional[LegacyExtractionAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = pydantic.Field(alias="advancedOptions", default=None)
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


class LegacyProcessorVersionConfig_Splitter(UncheckedBaseModel):
    """
    The configuration settings for this version of the document processor. The structure of this object will vary depending on the processor type.

    See the configuration section in the "Guides" tab, for yout specific processor type, for more details on the configuration settings.
    """

    type: typing.Literal["SPLITTER"] = "SPLITTER"
    base_processor: typing_extensions.Annotated[
        typing.Optional[LegacySplitterConfigBaseProcessor], FieldMetadata(alias="baseProcessor")
    ] = pydantic.Field(alias="baseProcessor", default=None)
    base_version: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="baseVersion")] = (
        pydantic.Field(alias="baseVersion", default=None)
    )
    split_classifications: typing_extensions.Annotated[
        typing.List[LegacyClassification], FieldMetadata(alias="splitClassifications")
    ] = pydantic.Field(alias="splitClassifications")
    split_rules: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="splitRules")] = pydantic.Field(
        alias="splitRules", default=None
    )
    advanced_options: typing_extensions.Annotated[
        typing.Optional[LegacySplitterAdvancedOptions], FieldMetadata(alias="advancedOptions")
    ] = pydantic.Field(alias="advancedOptions", default=None)
    parser: typing.Optional[ParseConfig] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


LegacyProcessorVersionConfig = typing_extensions.Annotated[
    typing.Union[
        LegacyProcessorVersionConfig_Classify,
        LegacyProcessorVersionConfig_Extract,
        LegacyProcessorVersionConfig_Splitter,
    ],
    UnionMetadata(discriminant="type"),
]
from .legacy_extraction_field import LegacyExtractionField  # noqa: E402, I001

update_forward_refs(LegacyProcessorVersionConfig_Extract, LegacyExtractionField=LegacyExtractionField)



# This file was auto-generated by Fern from our API Definition.

import typing

from ..core import enum

T_Result = typing.TypeVar("T_Result")


class BlockType(enum.StrEnum):
    """
    The type of block:
    * `"text"` - Regular text content
    * `"heading"` - Section or document headings
    * `"section_heading"` - Subsection headings
    * `"table"` - Tabular data with rows and columns
    * `"table_head"` - Table header cells
    * `"table_cell"` - Table body cells
    * `"figure"` - Images, charts, diagrams, or logos
    """

    TEXT = "text"
    HEADING = "heading"
    SECTION_HEADING = "section_heading"
    TABLE = "table"
    FIGURE = "figure"
    TABLE_HEAD = "table_head"
    TABLE_CELL = "table_cell"
    _UNKNOWN = "__BLOCKTYPE_UNKNOWN__"
    """
    This member is used for forward compatibility. If the value is not recognized by the enum, it will be stored here, and the raw value is accessible through `.value`.
    """

    @classmethod
    def _missing_(cls, value: typing.Any) -> "BlockType":
        unknown = cls._UNKNOWN
        unknown._value_ = value
        return unknown

    def visit(
        self,
        text: typing.Callable[[], T_Result],
        heading: typing.Callable[[], T_Result],
        section_heading: typing.Callable[[], T_Result],
        table: typing.Callable[[], T_Result],
        figure: typing.Callable[[], T_Result],
        table_head: typing.Callable[[], T_Result],
        table_cell: typing.Callable[[], T_Result],
        _unknown_member: typing.Callable[[str], T_Result],
    ) -> T_Result:
        if self is BlockType.TEXT:
            return text()
        if self is BlockType.HEADING:
            return heading()
        if self is BlockType.SECTION_HEADING:
            return section_heading()
        if self is BlockType.TABLE:
            return table()
        if self is BlockType.FIGURE:
            return figure()
        if self is BlockType.TABLE_HEAD:
            return table_head()
        if self is BlockType.TABLE_CELL:
            return table_cell()
        return _unknown_member(self._value_)



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from ..types.created_at import CreatedAt


class ClassifierVersionSummaryParams(typing_extensions.TypedDict):
    object: typing.Literal["classifier_version"]
    """
    The type of object. Will always be `"classifier_version"`.
    """

    id: str
    """
    The unique identifier for this version of the classifier.
    
    Example: `"clv_xK9mLPqRtN3vS8wF5hB2cQ"`
    """

    description: typing.Optional[str]
    """
    A description of this version of the classifier.
    
    Example: `"Added new document types for Q4 processing"`
    """

    version: str
    """
    The version number or identifier for this specific version of the classifier. The draft version will have version="draft".
    
    Examples: `"1.0"`, `"2.1"`, `"draft"`
    """

    classifier_id: typing_extensions.Annotated[str, FieldMetadata(alias="classifierId")]
    """
    The ID of the classifier that this version belongs to.
    
    Example: `"cl_Xj8mK2pL9nR4vT7qY5wZ"`
    """

    created_at: typing_extensions.Annotated[CreatedAt, FieldMetadata(alias="createdAt")]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.serialization import FieldMetadata
from ..core.unchecked_base_model import UncheckedBaseModel


class SplitClassification(UncheckedBaseModel):
    """
    A classification for document splitting. Extends the base Classification with an optional `identifierKey` field for per-type identifier extraction rules.
    """

    id: str = pydantic.Field()
    """
    Unique identifier for the classification. We recommend lowercase, underscore-separated format.
    """

    type: str = pydantic.Field()
    """
    Type identifier for the classification.
    """

    description: str = pydantic.Field()
    """
    A detailed description of the classification.
    """

    identifier_key: typing_extensions.Annotated[typing.Optional[str], FieldMetadata(alias="identifierKey")] = (
        pydantic.Field(alias="identifierKey", default=None)
    )
    """
    A natural-language rule describing how to extract a unique identifier for subdocuments of this type. For example, `"Extract the invoice number from the document header"`.
    
    When provided, the splitter will extract the specified identifier for each subdocument of this type and include it in the output as the `identifier` field. This enables merging of related subdocuments that share the same extracted identifier.
    
    **Availability:** Supported on `splitting_light` >= 1.3.0 and `splitting_performance` >= 1.5.0. If provided on older versions, this field is accepted but ignored.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import typing_extensions
from ..core.serialization import FieldMetadata
from .edit_json import EditJsonParams


class EditRootJsonParams(typing_extensions.TypedDict):
    """
    JSON Schema definition for editing PDF documents. The schema defines the structure and placement of fields to edit.
    """

    type: typing.Literal["object"]
    """
    Must be "object" for the root schema
    """

    properties: typing.Dict[str, EditJsonParams]
    """
    Map of field names to their schema definitions
    """

    required: typing_extensions.NotRequired[typing.Sequence[str]]
    """
    List of required field names
    """

    additional_properties: typing_extensions.NotRequired[
        typing_extensions.Annotated[bool, FieldMetadata(alias="additionalProperties")]
    ]
    """
    Whether additional properties are allowed
    """
